@@ -33,7 +33,7 @@
 #include <tdefiledialog.h>
 #include <tdeglobalsettings.h>
 #include <tdehtmldefaults.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdemainwindow.h>
 #include <tdemessagebox.h>
 #include <knotifyclient.h>
