@@ -62,7 +62,7 @@
 namespace Akregator {
 
 BrowserInterface::BrowserInterface( MainWindow *shell, const char *name )
-    : KParts::BrowserInterface( TQT_TQOBJECT(shell), name )
+    : KParts::BrowserInterface( shell, name )
 {
     m_shell = shell;
 }
@@ -104,16 +104,16 @@ bool MainWindow::loadPart()
     {
         // now that the Part is loaded, we cast it to a Part to get
         // our hands on it
-        m_part = static_cast<Akregator::Part*>(factory->create(TQT_TQOBJECT(this), "akregator_part", "KParts::ReadOnlyPart" ));
+        m_part = static_cast<Akregator::Part*>(factory->create(this, "akregator_part", "KParts::ReadOnlyPart" ));
 
         if (m_part)
         {
             // tell the KParts::MainWindow that this is indeed the main widget
             setCentralWidget(m_part->widget());
 
-            connect(m_part, TQT_SIGNAL(setWindowCaption (const TQString &)), this, TQT_SLOT(setCaption (const TQString &)));
+            connect(m_part, TQ_SIGNAL(setWindowCaption (const TQString &)), this, TQ_SLOT(setCaption (const TQString &)));
 
-            connect(TrayIcon::getInstance(), TQT_SIGNAL(quitSelected()), this, TQT_SLOT(slotQuit()));
+            connect(TrayIcon::getInstance(), TQ_SIGNAL(quitSelected()), this, TQ_SLOT(slotQuit()));
             // and integrate the part's GUI with the shell's
             connectActionCollection(m_part->actionCollection());
             createGUI(m_part);
@@ -154,13 +154,13 @@ void MainWindow::setupActions()
 {
     connectActionCollection(actionCollection());
 
-    KStdAction::quit(TQT_TQOBJECT(kapp), TQT_SLOT(quit()), actionCollection());
+    KStdAction::quit(kapp, TQ_SLOT(quit()), actionCollection());
 
     setStandardToolBarMenuEnabled(true);
     createStandardStatusBarAction();
 
-    KStdAction::keyBindings(TQT_TQOBJECT(this), TQT_SLOT(optionsConfigureKeys()), actionCollection());
-    KStdAction::configureToolbars(TQT_TQOBJECT(this), TQT_SLOT(optionsConfigureToolbars()), actionCollection());
+    KStdAction::keyBindings(this, TQ_SLOT(optionsConfigureKeys()), actionCollection());
+    KStdAction::configureToolbars(this, TQ_SLOT(optionsConfigureToolbars()), actionCollection());
 }
 
 void MainWindow::saveProperties(TDEConfig* config)
@@ -203,8 +203,8 @@ void MainWindow::optionsConfigureToolbars()
 
     // use the standard toolbar editor
     KEditToolbar dlg(factory());
-    connect(&dlg, TQT_SIGNAL(newToolbarConfig()),
-            this, TQT_SLOT(applyNewToolbarConfig()));
+    connect(&dlg, TQ_SIGNAL(newToolbarConfig()),
+            this, TQ_SLOT(applyNewToolbarConfig()));
     dlg.exec();
 }
 
@@ -226,10 +226,10 @@ KParts::BrowserExtension *MainWindow::browserExtension(KParts::ReadOnlyPart *p)
 void MainWindow::connectActionCollection( TDEActionCollection *coll )
 {
     if (!coll) return;
-    connect( coll, TQT_SIGNAL( actionStatusText( const TQString & ) ),
-              m_statusLabel, TQT_SLOT( setText( const TQString & ) ) );
-    connect( coll, TQT_SIGNAL( clearStatusText() ),
-             this, TQT_SLOT( slotClearStatusText() ) );
+    connect( coll, TQ_SIGNAL( actionStatusText( const TQString & ) ),
+              m_statusLabel, TQ_SLOT( setText( const TQString & ) ) );
+    connect( coll, TQ_SIGNAL( clearStatusText() ),
+             this, TQ_SLOT( slotClearStatusText() ) );
 }
 
 bool MainWindow::queryExit()
@@ -285,6 +285,3 @@ void MainWindow::slotSetStatusBarText( const TQString & text )
 } // namespace Akregator
 
 #include "mainwindow.moc"
-
-
-// vim: set et ts=4 sts=4 sw=4:
