@@ -240,12 +240,12 @@ class CryptPlugWrapper;
   any of it's members - just ignore the advise given in the
   cryptplug.h documentation!
 
-  <b>If</b> value returned in \c makeMimeObject is <b>TRUE</b> the
+  <b>If</b> value returned in \c makeMimeObject is <b>true</b> the
   text strings returned in \c contentTypeMain and \c contentDispMain
   and \c contentTEncMain (and, if required, \c content[..]Version and
   \c bodyTextVersion and \c content[..]Sig) should be used to compose
   a respective MIME object.<br>
-  If <b>FALSE</b> the texts returned in \c flatTextPrefix and
+  If <b>false</b> the texts returned in \c flatTextPrefix and
   \c flatTextSeparator and \c flatTextPostfix are to be used instead.<br>
   Always <b>either</b> the \c content[..] and \c bodyTextVersion
   parameters <b>or</b> the \c flatText[..] parameters are holding
@@ -273,16 +273,16 @@ class CryptPlugWrapper;
   you could report the missing MIME header information to the address
   returned by the \c bugURL() function.
 
-  If \c makeMultiMime returns FALSE the \c contentTypeMain returned must
+  If \c makeMultiMime returns false the \c contentTypeMain returned must
   not be altered but used to specify a single part mime object holding the
   code bloc, e.g. this is used for 'enveloped-data' single part MIME
   objects. In this case you should ignore both the \c content[..]Version
   and \c content[..]Code parameters.
 
-  If \c makeMultiMime returns TRUE also the following rules apply:
-  \li If \c includeCleartext is TRUE you should include the cleartext
-  as first part of our multipart MIME object, typically this is TRUE
-  when signing mails but FALSE when encrypting.
+  If \c makeMultiMime returns true also the following rules apply:
+  \li If \c includeCleartext is true you should include the cleartext
+  as first part of our multipart MIME object, typically this is true
+  when signing mails but false when encrypting.
   \li The \c contentTypeMain returned typically starts with
   "multipart/" while providing a "protocol" and a "micalg" parameter: just
   add an appropriate \c "; boundary=[your \c boundary \c string]" to get
@@ -308,16 +308,16 @@ class CryptPlugWrapper;
   unaltered value to specify the Content-Transfer-Encoding header of
   the respective MIME part.
 
-  <b>If</b> value returned in \c makeMimeObject is <b>FALSE</b> the
+  <b>If</b> value returned in \c makeMimeObject is <b>false</b> the
   text strings returned in \c flatTextPrefix and \c flatTextPostfix
   should be used to build a frame around the cleartext and the code
   bloc holding the signature (or - in case of encrypting - the encoded
   data bloc, resp.).<br>
-  If \c includeCleartext is TRUE this frame should also include the
+  If \c includeCleartext is true this frame should also include the
   cleartext as first bloc, this bloc should be divided from the code bloc
   by the contents of \c flatTextSeparator - typically this is used for
   signing but not when encrypting.<br>
-  If \c includeCleartext is FALSE you should ignore both the cleartext
+  If \c includeCleartext is false you should ignore both the cleartext
   and the \c flatTextSeparator parameter.
 
   <b>How to use StructuringInfoWrapper data in your program:</b>
