@@ -33,7 +33,7 @@
 #define CRYPTOCONFIGDIALOG_H
 
 #include <kdialogbase.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 namespace Kleo {
 
@@ -43,7 +43,7 @@ namespace Kleo {
   /**
    * Simple KDialogBase wrapper around CryptoConfigModule
    */
-  class KDE_EXPORT CryptoConfigDialog : public KDialogBase
+  class TDE_EXPORT CryptoConfigDialog : public KDialogBase
   {
     TQ_OBJECT
   
