@@ -353,7 +353,7 @@ Kleo::CryptoConfigEntryGUI::CryptoConfigEntryGUI(
   const char* name )
   : TQObject( module, name ), mEntry( entry ), mName( entryName ), mChanged( false )
 {
-  connect( this, TQT_SIGNAL( changed() ), module, TQT_SIGNAL( changed() ) );
+  connect( this, TQ_SIGNAL( changed() ), module, TQ_SIGNAL( changed() ) );
 }
 
 TQString Kleo::CryptoConfigEntryGUI::description() const
@@ -387,7 +387,7 @@ Kleo::CryptoConfigEntryLineEdit::CryptoConfigEntryLineEdit(
     label->setEnabled( false );
     mLineEdit->setEnabled( false );
   } else {
-    connect( mLineEdit, TQT_SIGNAL( textChanged( const TQString& ) ), TQT_SLOT( slotChanged() ) );
+    connect( mLineEdit, TQ_SIGNAL( textChanged( const TQString& ) ), TQ_SLOT( slotChanged() ) );
   }
 }
 
@@ -419,7 +419,7 @@ Kleo::CryptoConfigEntryPath::CryptoConfigEntryPath(
     label->setEnabled( false );
     mUrlRequester->setEnabled( false );
   } else {
-    connect( mUrlRequester, TQT_SIGNAL( textChanged( const TQString& ) ), TQT_SLOT( slotChanged() ) );
+    connect( mUrlRequester, TQ_SIGNAL( textChanged( const TQString& ) ), TQ_SLOT( slotChanged() ) );
   }
 }
 
@@ -453,7 +453,7 @@ Kleo::CryptoConfigEntryDirPath::CryptoConfigEntryDirPath(
     label->setEnabled( false );
     mUrlRequester->setEnabled( false );
   } else {
-    connect( mUrlRequester, TQT_SIGNAL( textChanged( const TQString& ) ), TQT_SLOT( slotChanged() ) );
+    connect( mUrlRequester, TQ_SIGNAL( textChanged( const TQString& ) ), TQ_SLOT( slotChanged() ) );
   }
 }
 
@@ -488,7 +488,7 @@ Kleo::CryptoConfigEntryURL::CryptoConfigEntryURL(
     label->setEnabled( false );
     mUrlRequester->setEnabled( false );
   } else {
-    connect( mUrlRequester, TQT_SIGNAL( textChanged( const TQString& ) ), TQT_SLOT( slotChanged() ) );
+    connect( mUrlRequester, TQ_SIGNAL( textChanged( const TQString& ) ), TQ_SLOT( slotChanged() ) );
   }
 }
 
@@ -532,7 +532,7 @@ Kleo::CryptoConfigEntrySpinBox::CryptoConfigEntrySpinBox(
   } else {
     if ( mKind == UInt || mKind == ListOfNone )
       mNumInput->setMinValue( 0 );
-    connect( mNumInput, TQT_SIGNAL( valueChanged(int) ), TQT_SLOT( slotChanged() ) );
+    connect( mNumInput, TQ_SIGNAL( valueChanged(int) ), TQ_SLOT( slotChanged() ) );
   }
 }
 
@@ -584,7 +584,7 @@ Kleo::CryptoConfigEntryCheckBox::CryptoConfigEntryCheckBox(
   if ( entry->isReadOnly() ) {
     mCheckBox->setEnabled( false );
   } else {
-    connect( mCheckBox, TQT_SIGNAL( toggled(bool) ), TQT_SLOT( slotChanged() ) );
+    connect( mCheckBox, TQ_SIGNAL( toggled(bool) ), TQ_SLOT( slotChanged() ) );
   }
 }
 
@@ -619,7 +619,7 @@ Kleo::CryptoConfigEntryLDAPURL::CryptoConfigEntryLDAPURL(
     mLabel->setEnabled( false );
     mPushButton->hide();
   } else {
-    connect( mPushButton, TQT_SIGNAL( clicked() ), TQT_SLOT( slotOpenDialog() ) );
+    connect( mPushButton, TQ_SIGNAL( clicked() ), TQ_SLOT( slotOpenDialog() ) );
   }
 }
 
@@ -644,7 +644,7 @@ void Kleo::CryptoConfigEntryLDAPURL::slotOpenDialog()
   DirectoryServicesWidget* dirserv = new DirectoryServicesWidget( mEntry, &dialog );
   dirserv->load();
   dialog.setMainWidget( dirserv );
-  connect( &dialog, TQT_SIGNAL( defaultClicked() ), dirserv, TQT_SLOT( defaults() ) );
+  connect( &dialog, TQ_SIGNAL( defaultClicked() ), dirserv, TQ_SLOT( defaults() ) );
   if ( dialog.exec() ) {
     // Note that we just grab the urls from the dialog, we don't call its save method,
     // since the user hasn't confirmed the big config dialog yet.
