@@ -45,7 +45,7 @@
 #include <tqstring.h>
 
 class KDHorizontalLine : public TQFrame {
-  Q_OBJECT
+  TQ_OBJECT
   
   TQ_PROPERTY( TQString title READ title WRITE setTitle )
 public:
