@@ -1,4 +1,4 @@
-/*  -*- c++ -*-
+/*
     keyselectiondialog.cpp
 
     This file is part of libkleopatra, the KDE keymanagement library
@@ -377,8 +377,8 @@ void Kleo::KeySelectionDialog::init( bool rememberChoice, bool extendedSelection
   if ( !text.isEmpty() ) {
     if ( text.startsWith( "<qt>" ) ) {
       KActiveLabel *textLabel = new KActiveLabel( text, page );
-      disconnect( textLabel, TQT_SIGNAL(linkClicked(const TQString&)), textLabel, TQT_SLOT(openLink(const TQString&)) );
-      connect( textLabel, TQT_SIGNAL(linkClicked(const TQString&)), TQT_SLOT(slotStartCertificateManager(const TQString&)) );
+      disconnect( textLabel, TQ_SIGNAL(linkClicked(const TQString&)), textLabel, TQ_SLOT(openLink(const TQString&)) );
+      connect( textLabel, TQ_SIGNAL(linkClicked(const TQString&)), TQ_SLOT(slotStartCertificateManager(const TQString&)) );
       textLabel->setAlignment( textLabel->alignment() | TQt::WordBreak );
       mTopLayout->addWidget( textLabel );
     } else {
@@ -391,7 +391,7 @@ void Kleo::KeySelectionDialog::init( bool rememberChoice, bool extendedSelection
   TQPushButton * const searchExternalPB
       = new TQPushButton( i18n("Search for &External Certificates"), page );
   mTopLayout->addWidget( searchExternalPB, 0, TQt::AlignLeft );
-  connect( searchExternalPB, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotStartSearchForExternalCertificates()) );
+  connect( searchExternalPB, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotStartSearchForExternalCertificates()) );
   if ( initialQuery.isEmpty() )
       searchExternalPB->hide();
 
@@ -406,10 +406,10 @@ void Kleo::KeySelectionDialog::init( bool rememberChoice, bool extendedSelection
   hlay->addWidget( le, 1 );
   le->setFocus();
 
-  connect( clearButton, TQT_SIGNAL( clicked() ), le, TQT_SLOT( clear() ) );
-  connect( le, TQT_SIGNAL(textChanged(const TQString&)),
-	   this, TQT_SLOT(slotSearch(const TQString&)) );
-  connect( mStartSearchTimer, TQT_SIGNAL(timeout()), TQT_SLOT(slotFilter()) );
+  connect( clearButton, TQ_SIGNAL( clicked() ), le, TQ_SLOT( clear() ) );
+  connect( le, TQ_SIGNAL(textChanged(const TQString&)),
+	   this, TQ_SLOT(slotSearch(const TQString&)) );
+  connect( mStartSearchTimer, TQ_SIGNAL(timeout()), TQ_SLOT(slotFilter()) );
 
   mKeyListView = new KeyListView( new ColumnStrategy( mKeyUsage ), 0, page, "mKeyListView" );
   mKeyListView->setResizeMode( TQListView::LastColumn );
@@ -430,21 +430,21 @@ void Kleo::KeySelectionDialog::init( bool rememberChoice, bool extendedSelection
 			  "</p></qt>") );
   }
 
-  connect( mCheckSelectionTimer, TQT_SIGNAL(timeout()),
-	   TQT_SLOT(slotCheckSelection()) );
+  connect( mCheckSelectionTimer, TQ_SIGNAL(timeout()),
+	   TQ_SLOT(slotCheckSelection()) );
   connectSignals();
 
   connect( mKeyListView,
-	   TQT_SIGNAL(doubleClicked(Kleo::KeyListViewItem*,const TQPoint&,int)),
-	   TQT_SLOT(slotTryOk()) );
+	   TQ_SIGNAL(doubleClicked(Kleo::KeyListViewItem*,const TQPoint&,int)),
+	   TQ_SLOT(slotTryOk()) );
   connect( mKeyListView,
-	   TQT_SIGNAL(contextMenu(Kleo::KeyListViewItem*,const TQPoint&)),
-           TQT_SLOT(slotRMB(Kleo::KeyListViewItem*,const TQPoint&)) );
+	   TQ_SIGNAL(contextMenu(Kleo::KeyListViewItem*,const TQPoint&)),
+           TQ_SLOT(slotRMB(Kleo::KeyListViewItem*,const TQPoint&)) );
 
   setButtonText( KDialogBase::Default, i18n("&Reread Keys") );
   setButtonGuiItem( KDialogBase::Help, i18n("&Start Certificate Manager") );
-  connect( this, TQT_SIGNAL(defaultClicked()), this, TQT_SLOT(slotRereadKeys()) );
-  connect( this, TQT_SIGNAL(helpClicked()), this, TQT_SLOT(slotStartCertificateManager()) );
+  connect( this, TQ_SIGNAL(defaultClicked()), this, TQ_SLOT(slotRereadKeys()) );
+  connect( this, TQ_SIGNAL(helpClicked()), this, TQ_SLOT(slotStartCertificateManager()) );
 
   slotRereadKeys();
   mTopLayout->activate();
@@ -468,20 +468,20 @@ Kleo::KeySelectionDialog::~KeySelectionDialog() {
 
 void Kleo::KeySelectionDialog::connectSignals() {
   if ( mKeyListView->isMultiSelection() )
-    connect( mKeyListView, TQT_SIGNAL(selectionChanged()),
-             TQT_SLOT(slotSelectionChanged()) );
+    connect( mKeyListView, TQ_SIGNAL(selectionChanged()),
+             TQ_SLOT(slotSelectionChanged()) );
   else
-    connect( mKeyListView, TQT_SIGNAL(selectionChanged(Kleo::KeyListViewItem*)),
-             TQT_SLOT(slotCheckSelection(Kleo::KeyListViewItem*)) );
+    connect( mKeyListView, TQ_SIGNAL(selectionChanged(Kleo::KeyListViewItem*)),
+             TQ_SLOT(slotCheckSelection(Kleo::KeyListViewItem*)) );
 }
 
 void Kleo::KeySelectionDialog::disconnectSignals() {
   if ( mKeyListView->isMultiSelection() )
-    disconnect( mKeyListView, TQT_SIGNAL(selectionChanged()),
-		this, TQT_SLOT(slotSelectionChanged()) );
+    disconnect( mKeyListView, TQ_SIGNAL(selectionChanged()),
+		this, TQ_SLOT(slotSelectionChanged()) );
   else
-    disconnect( mKeyListView, TQT_SIGNAL(selectionChanged(Kleo::KeyListViewItem*)),
-		this, TQT_SLOT(slotCheckSelection(Kleo::KeyListViewItem*)) );
+    disconnect( mKeyListView, TQ_SIGNAL(selectionChanged(Kleo::KeyListViewItem*)),
+		this, TQ_SLOT(slotCheckSelection(Kleo::KeyListViewItem*)) );
 }
 
 const GpgME::Key & Kleo::KeySelectionDialog::selectedKey() const {
@@ -593,12 +593,12 @@ void Kleo::KeySelectionDialog::startKeyListJobForBackend( const CryptoBackend::P
     return;
   }
 
-  connect( job, TQT_SIGNAL(result(const GpgME::KeyListResult&)),
-	   TQT_SLOT(slotKeyListResult(const GpgME::KeyListResult&)) );
-  connect( job, TQT_SIGNAL(nextKey(const GpgME::Key&)),
+  connect( job, TQ_SIGNAL(result(const GpgME::KeyListResult&)),
+	   TQ_SLOT(slotKeyListResult(const GpgME::KeyListResult&)) );
+  connect( job, TQ_SIGNAL(nextKey(const GpgME::Key&)),
 	   mKeyListView, validate ?
-	   TQT_SLOT(slotRefreshKey(const GpgME::Key&)) :
-	   TQT_SLOT(slotAddKey(const GpgME::Key&)) );
+	   TQ_SLOT(slotRefreshKey(const GpgME::Key&)) :
+	   TQ_SLOT(slotAddKey(const GpgME::Key&)) );
 
   TQStringList fprs;
   std::transform( keys.begin(), keys.end(), std::back_inserter( fprs ), ExtractFingerprint() );
@@ -756,7 +756,7 @@ void Kleo::KeySelectionDialog::slotRMB( Kleo::KeyListViewItem * item, const TQPo
   mCurrentContextMenuItem = item;
 
   TQPopupMenu menu;
-  menu.insertItem( i18n( "Recheck Key" ), this, TQT_SLOT(slotRecheckKey()) );
+  menu.insertItem( i18n( "Recheck Key" ), this, TQ_SLOT(slotRecheckKey()) );
   menu.exec( p );
 }
 
