@@ -23,7 +23,7 @@ class Core;
 
 class DistributionListEntryView : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
