@@ -30,7 +30,7 @@ class KABConfigWidget;
 
 class KCMKabConfig : public TDECModule
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
