@@ -323,7 +323,7 @@ DateTime DcopHandler::convertStartDateTime(const TQString& startDateTime)
 	if (startDateTime.length() > 10)
 	{
 		// Both a date and a time are specified
-		start = TQDateTime::fromString(startDateTime, Qt::ISODate);
+		start = TQDateTime::fromString(startDateTime, TQt::ISODate);
 	}
 	else
 	{
@@ -337,12 +337,12 @@ DateTime DcopHandler::convertStartDateTime(const TQString& startDateTime)
 		if (t.isEmpty())
 		{
 			// It's a date
-			start = TQDate::fromString(startDateTime, Qt::ISODate);
+			start = TQDate::fromString(startDateTime, TQt::ISODate);
 		}
 		else
 		{
 			// It's a time, so use today as the date
-			start.set(TQDate::currentDate(), TQTime::fromString(t, Qt::ISODate));
+			start.set(TQDate::currentDate(), TQTime::fromString(t, TQt::ISODate));
 		}
 	}
 	if (!start.isValid())
@@ -424,7 +424,7 @@ bool DcopHandler::convertRecurrence(DateTime& start, KARecurrence& recurrence, c
 			kdError(5950) << "DCOP call: alarm is date-only, but recurrence end is date/time" << endl;
 			return false;
 		}
-		end.setDate(TQDate::fromString(endDateTime, Qt::ISODate));
+		end.setDate(TQDate::fromString(endDateTime, TQt::ISODate));
 	}
 	else
 	{
@@ -433,7 +433,7 @@ bool DcopHandler::convertRecurrence(DateTime& start, KARecurrence& recurrence, c
 			kdError(5950) << "DCOP call: alarm is timed, but recurrence end is date-only" << endl;
 			return false;
 		}
-		end = TQDateTime::fromString(endDateTime, Qt::ISODate);
+		end = TQDateTime::fromString(endDateTime, TQt::ISODate);
 	}
 	if (!end.isValid())
 	{
