@@ -944,7 +944,7 @@ TQString KAMail::getMailBody(TQ_UINT32 serialNumber)
 	arg << (int)0;
 	TQString body;
 	if (kapp->dcopClient()->call("kmail", "KMailIface", "getDecodedBodyPart(TQ_UINT32,int)", data, replyType, replyData)
-	&&  replyType == TQSTRING_OBJECT_NAME_STRING)
+	&&  replyType == "TQString")
 	{
 		TQDataStream reply_stream(replyData, IO_ReadOnly);
 		reply_stream >> body;
