@@ -1,4 +1,4 @@
-/* -*- Mode: C++ -*-
+/*
    $Id$
 */
 
@@ -55,7 +55,7 @@ static int mouseOffset;
 static int opaqueOldPos = -1; //### there's only one mouse, but this is a bit risky
 
 
-KDGanttSplitterHandle::KDGanttSplitterHandle( Qt::Orientation o,
+KDGanttSplitterHandle::KDGanttSplitterHandle( TQt::Orientation o,
 				  KDGanttMinimizeSplitter *parent, const char * name )
     : TQWidget( parent, name ), _activeButton( 0 ), _collapsed( false )
 {
@@ -69,11 +69,11 @@ TQSize KDGanttSplitterHandle::sizeHint() const
     return TQSize(8,8);
 }
 
-void KDGanttSplitterHandle::setOrientation( Qt::Orientation o )
+void KDGanttSplitterHandle::setOrientation( TQt::Orientation o )
 {
     orient = o;
 #ifndef TQT_NO_CURSOR
-    if ( o == Qt::Horizontal )
+    if ( o == TQt::Horizontal )
 	setCursor( splitHCursor );
     else
 	setCursor( splitVCursor );
@@ -84,7 +84,7 @@ void KDGanttSplitterHandle::setOrientation( Qt::Orientation o )
 void KDGanttSplitterHandle::mouseMoveEvent( TQMouseEvent *e )
 {
     updateCursor( e->pos() );
-    if ( !(e->state()&Qt::LeftButton) )
+    if ( !(e->state()&TQt::LeftButton) )
 	return;
 
     if ( _activeButton != 0)
@@ -104,7 +104,7 @@ void KDGanttSplitterHandle::mouseMoveEvent( TQMouseEvent *e )
 
 void KDGanttSplitterHandle::mousePressEvent( TQMouseEvent *e )
 {
-    if ( e->button() == Qt::LeftButton ) {
+    if ( e->button() == TQt::LeftButton ) {
         _activeButton = onButton( e->pos() );
         mouseOffset = s->pick(e->pos());
         if ( _activeButton != 0)
@@ -119,7 +119,7 @@ void KDGanttSplitterHandle::updateCursor( const TQPoint& p)
         setCursor( arrowCursor );
     }
     else {
-        if ( orient == Qt::Horizontal )
+        if ( orient == TQt::Horizontal )
             setCursor( splitHCursor );
         else
             setCursor( splitVCursor );
@@ -158,7 +158,7 @@ void KDGanttSplitterHandle::mouseReleaseEvent( TQMouseEvent *e )
         updateCursor( e->pos() );
     }
     else {
-        if ( !opaque() && e->button() == Qt::LeftButton ) {
+        if ( !opaque() && e->button() == TQt::LeftButton ) {
             TQCOORD pos = s->pick(parentWidget()->mapFromGlobal(e->globalPos()))
                 - mouseOffset;
             s->setRubberband( -1 );
@@ -241,7 +241,7 @@ void KDGanttSplitterHandle::paintEvent( TQPaintEvent * )
     p.setBrush( colorGroup().background() );
     p.setPen( colorGroup().foreground() );
     p.drawRect( rect() );
-    parentWidget()->style().tqdrawPrimitive( TQStyle::PE_Panel, &p, rect(),
+    parentWidget()->style().drawPrimitive( TQStyle::PE_Panel, &p, rect(),
                                            parentWidget()->colorGroup());
 
     int sw = 8; // Hardcoded, given I didn't use styles anymore, I didn't like to use their size
@@ -295,7 +295,7 @@ public:
 class TQSplitterData
 {
 public:
-    TQSplitterData() : opaque( FALSE ), firstShow( TRUE ) {}
+    TQSplitterData() : opaque( false ), firstShow( true ) {}
 
     TQPtrList<TQSplitterLayoutStruct> list;
     bool opaque;
@@ -340,7 +340,7 @@ void kdganttGeomCalc( TQMemArray<TQLayoutStruct> &chain, int start, int count, i
   that a widget should keep its size when the splitter is resized.
 
   Although KDGanttMinimizeSplitter normally resizes the children only
-  at the end of a resize operation, if you call setOpaqueResize( TRUE
+  at the end of a resize operation, if you call setOpaqueResize( true
   ) the widgets are resized as often as possible.
 
   The initial distribution of size between the widgets is determined
@@ -384,7 +384,7 @@ static TQSize minSizeHint( const TQWidget* w )
 KDGanttMinimizeSplitter::KDGanttMinimizeSplitter( TQWidget *parent, const char *name )
     :TQFrame(parent,name,WPaintUnclipped)
 {
-     orient = Qt::Horizontal;
+     orient = TQt::Horizontal;
      init();
 }
 
@@ -392,7 +392,7 @@ KDGanttMinimizeSplitter::KDGanttMinimizeSplitter( TQWidget *parent, const char *
   Constructs a splitter with orientation \a o with the \a parent
   and \a name arguments being passed on to the TQFrame constructor.
 */
-KDGanttMinimizeSplitter::KDGanttMinimizeSplitter( Qt::Orientation o, TQWidget *parent, const char *name )
+KDGanttMinimizeSplitter::KDGanttMinimizeSplitter( TQt::Orientation o, TQWidget *parent, const char *name )
     :TQFrame(parent,name,WPaintUnclipped)
 {
      orient = o;
@@ -404,7 +404,7 @@ KDGanttMinimizeSplitter::KDGanttMinimizeSplitter( Qt::Orientation o, TQWidget *p
 */
 KDGanttMinimizeSplitter::~KDGanttMinimizeSplitter()
 {
-    data->list.setAutoDelete( TRUE );
+    data->list.setAutoDelete( true );
     delete data;
 }
 
@@ -412,7 +412,7 @@ KDGanttMinimizeSplitter::~KDGanttMinimizeSplitter()
 void KDGanttMinimizeSplitter::init()
 {
     data = new TQSplitterData;
-    if ( orient == Qt::Horizontal )
+    if ( orient == TQt::Horizontal )
 	setSizePolicy( TQSizePolicy(TQSizePolicy::Expanding,TQSizePolicy::Minimum) );
     else
 	setSizePolicy( TQSizePolicy(TQSizePolicy::Minimum,TQSizePolicy::Expanding) );
@@ -424,15 +424,15 @@ void KDGanttMinimizeSplitter::init()
   \brief the orientation of the splitter
 
   By default the orientation is horizontal (the widgets are side by side).
-  The possible orientations are TQt:Vertical and Qt::Horizontal (the default).
+  The possible orientations are TQt:Vertical and TQt::Horizontal (the default).
 */
-void KDGanttMinimizeSplitter::setOrientation( Qt::Orientation o )
+void KDGanttMinimizeSplitter::setOrientation( TQt::Orientation o )
 {
     if ( orient == o )
 	return;
     orient = o;
 
-    if ( orient == Qt::Horizontal )
+    if ( orient == TQt::Horizontal )
 	setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Minimum ) );
     else
 	setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Expanding ) );
@@ -458,11 +458,11 @@ void KDGanttMinimizeSplitter::resizeEvent( TQResizeEvent * )
 
 /*
   Inserts the widget \a w at the end (or at the beginning if \a first
-  is TRUE) of the splitter's list of widgets.
+  is true) of the splitter's list of widgets.
 
   It is the responsibility of the caller of this function to make sure
   that \a w is not already in the splitter and to call recalcId if
-  needed.  (If \a first is TRUE, then recalcId is very probably
+  needed.  (If \a first is true, then recalcId is very probably
   needed.)
 */
 TQSplitterLayoutStruct *KDGanttMinimizeSplitter::addWidget( TQWidget *w, bool first )
@@ -477,7 +477,7 @@ TQSplitterLayoutStruct *KDGanttMinimizeSplitter::addWidget( TQWidget *w, bool fi
 	newHandle = new KDGanttSplitterHandle( orientation(), this, tmp.latin1() );
 	s->wid = newHandle;
 	newHandle->setId(data->list.count());
-	s->isSplitter = TRUE;
+	s->isSplitter = true;
 	s->sizer = pick( newHandle->sizeHint() );
 	if ( first )
 	    data->list.insert( 0, s );
@@ -491,7 +491,7 @@ TQSplitterLayoutStruct *KDGanttMinimizeSplitter::addWidget( TQWidget *w, bool fi
 	s->sizer = pick( w->sizeHint() );
     else
 	s->sizer = pick( w->size() );
-    s->isSplitter = FALSE;
+    s->isSplitter = false;
     if ( first )
 	data->list.insert( 0, s );
     else
@@ -562,7 +562,7 @@ void KDGanttMinimizeSplitter::setRubberband( int p )
     TQRect r = contentsRect();
     const int rBord = 3; //Themable????
     int sw = style().pixelMetric(TQStyle::PM_SplitterWidth, this);
-    if ( orient == Qt::Horizontal ) {
+    if ( orient == TQt::Horizontal ) {
 	if ( opaqueOldPos >= 0 )
 	    paint.drawRect( opaqueOldPos + sw/2 - rBord , r.y(),
 			    2*rBord, r.height() );
@@ -585,7 +585,7 @@ bool KDGanttMinimizeSplitter::event( TQEvent *e )
     if ( e->type() == TQEvent::LayoutHint || ( e->type() == TQEvent::Show && data->firstShow ) ) {
 	recalc( isVisible() );
 	if ( e->type() == TQEvent::Show )
-	    data->firstShow = FALSE;
+	    data->firstShow = false;
     }
     return TQWidget::event( e );
 }
@@ -601,8 +601,8 @@ bool KDGanttMinimizeSplitter::event( TQEvent *e )
 void KDGanttMinimizeSplitter::drawSplitter( TQPainter *p,
 			      TQCOORD x, TQCOORD y, TQCOORD w, TQCOORD h )
 {
-    style().tqdrawPrimitive(TQStyle::PE_Splitter, p, TQRect(x, y, w, h), colorGroup(),
-			  (orientation() == Qt::Horizontal ?
+    style().drawPrimitive(TQStyle::PE_Splitter, p, TQRect(x, y, w, h), colorGroup(),
+			  (orientation() == TQt::Horizontal ?
 			   TQStyle::Style_Horizontal : 0));
 }
 
@@ -615,12 +615,12 @@ void KDGanttMinimizeSplitter::drawSplitter( TQPainter *p,
 int KDGanttMinimizeSplitter::idAfter( TQWidget* w ) const
 {
     TQSplitterLayoutStruct *s = data->list.first();
-    bool seen_w = FALSE;
+    bool seen_w = false;
     while ( s ) {
 	if ( s->isSplitter && seen_w )
 	    return data->list.at();
 	if ( !s->isSplitter && s->wid == w )
-	    seen_w = TRUE;
+	    seen_w = true;
 	s = data->list.next();
     }
     return 0;
@@ -644,9 +644,9 @@ void KDGanttMinimizeSplitter::moveSplitter( TQCOORD p, int id )
     p = adjustPos( p, id );
 
     TQSplitterLayoutStruct *s = data->list.at(id);
-    int oldP = orient == Qt::Horizontal ? s->wid->x() : s->wid->y();
+    int oldP = orient == TQt::Horizontal ? s->wid->x() : s->wid->y();
     bool upLeft;
-    if ( TQApplication::reverseLayout() && orient == Qt::Horizontal ) {
+    if ( TQApplication::reverseLayout() && orient == TQt::Horizontal ) {
 	p += s->wid->width();
 	upLeft = p > oldP;
     } else
@@ -661,8 +661,8 @@ void KDGanttMinimizeSplitter::moveSplitter( TQCOORD p, int id )
 
 void KDGanttMinimizeSplitter::setG( TQWidget *w, int p, int s, bool isSplitter )
 {
-    if ( orient == Qt::Horizontal ) {
-	if ( TQApplication::reverseLayout() && orient == Qt::Horizontal && !isSplitter )
+    if ( orient == TQt::Horizontal ) {
+	if ( TQApplication::reverseLayout() && orient == TQt::Horizontal && !isSplitter )
 	    p = contentsRect().width() - p - s;
 	w->setGeometry( p, contentsRect().y(), s, contentsRect().height() );
     } else
@@ -688,7 +688,7 @@ void KDGanttMinimizeSplitter::moveBefore( int pos, int id, bool upLeft )
     } else if ( s->isSplitter ) {
 	int pos1, pos2;
 	int dd = s->sizer;
-	if( TQApplication::reverseLayout() && orient == Qt::Horizontal ) {
+	if( TQApplication::reverseLayout() && orient == TQt::Horizontal ) {
 	    pos1 = pos;
 	    pos2 = pos + dd;
 	} else {
@@ -696,15 +696,15 @@ void KDGanttMinimizeSplitter::moveBefore( int pos, int id, bool upLeft )
 	    pos1 = pos2 + 1;
 	}
 	if ( upLeft ) {
-	    setG( w, pos1, dd, TRUE );
+	    setG( w, pos1, dd, true );
 	    moveBefore( pos2, id-1, upLeft );
 	} else {
 	    moveBefore( pos2, id-1, upLeft );
-	    setG( w, pos1, dd, TRUE );
+	    setG( w, pos1, dd, true );
 	}
     } else {
 	int dd, newLeft, nextPos;
-	if( TQApplication::reverseLayout() && orient == Qt::Horizontal ) {
+	if( TQApplication::reverseLayout() && orient == TQt::Horizontal ) {
 	    dd = w->geometry().right() - pos;
 	    dd = TQMAX( pick(minSize(w)), TQMIN(dd, pick(w->maximumSize())));
 	    newLeft = pos+1;
@@ -715,7 +715,7 @@ void KDGanttMinimizeSplitter::moveBefore( int pos, int id, bool upLeft )
 	    newLeft = pos-dd+1;
 	    nextPos = newLeft - 1;
 	}
-	setG( w, newLeft, dd, TRUE );
+	setG( w, newLeft, dd, true );
 	moveBefore( nextPos, id-1, upLeft );
     }
 }
@@ -741,7 +741,7 @@ void KDGanttMinimizeSplitter::moveAfter( int pos, int id, bool upLeft )
     } else if ( s->isSplitter ) {
 	int dd = s->sizer;
 	int pos1, pos2;
-	if( TQApplication::reverseLayout() && orient == Qt::Horizontal ) {
+	if( TQApplication::reverseLayout() && orient == TQt::Horizontal ) {
 	    pos2 = pos - dd;
 	    pos1 = pos2 + 1;
 	} else {
@@ -749,16 +749,16 @@ void KDGanttMinimizeSplitter::moveAfter( int pos, int id, bool upLeft )
 	    pos2 = pos + dd;
 	}
 	if ( upLeft ) {
-	    setG( w, pos1, dd, TRUE );
+	    setG( w, pos1, dd, true );
 	    moveAfter( pos2, id+1, upLeft );
 	} else {
 	    moveAfter( pos2, id+1, upLeft );
-	    setG( w, pos1, dd, TRUE );
+	    setG( w, pos1, dd, true );
 	}
     } else {
 	int left = pick( w->pos() );
 	int right, dd,/* newRight,*/ newLeft, nextPos;
-	if ( TQApplication::reverseLayout() && orient == Qt::Horizontal ) {
+	if ( TQApplication::reverseLayout() && orient == TQt::Horizontal ) {
 	    dd = pos - left + 1;
 	    dd = TQMAX( pick(minSize(w)), TQMIN(dd, pick(w->maximumSize())));
 	    newLeft = pos-dd+1;
@@ -771,7 +771,7 @@ void KDGanttMinimizeSplitter::moveAfter( int pos, int id, bool upLeft )
 	    newLeft = pos;
 	    nextPos = newLeft + dd;
 	}
-	setG( w, newLeft, dd, TRUE );
+	setG( w, newLeft, dd, true );
 	/*if( right != newRight )*/
 	moveAfter( nextPos, id+1, upLeft );
     }
@@ -836,7 +836,7 @@ void KDGanttMinimizeSplitter::getRange( int id, int *min, int *max )
 	}
     }
     TQRect r = contentsRect();
-    if ( orient == Qt::Horizontal && TQApplication::reverseLayout() ) {
+    if ( orient == TQt::Horizontal && TQApplication::reverseLayout() ) {
 	int splitterWidth = style().pixelMetric(TQStyle::PM_SplitterWidth, this);
 	if ( min )
 	    *min = pick(r.topRight()) - TQMIN( maxB, pick(r.size())-minA ) - splitterWidth;
@@ -884,23 +884,23 @@ void KDGanttMinimizeSplitter::doResize()
 	} else if ( s->isSplitter ) {
 	    a[i].stretch = 0;
 	    a[i].sizeHint = a[i].minimumSize = a[i].maximumSize = s->sizer;
-	    a[i].empty = FALSE;
+	    a[i].empty = false;
 	} else if ( s->mode == KeepSize ) {
 	    a[i].stretch = 0;
 	    a[i].minimumSize = pick( minSize(s->wid) );
 	    a[i].sizeHint = s->sizer;
 	    a[i].maximumSize = pick( s->wid->maximumSize() );
-	    a[i].empty = FALSE;
+	    a[i].empty = false;
 	} else if ( s->mode == FollowSizeHint ) {
 	    a[i].stretch = 0;
 	    a[i].minimumSize = a[i].sizeHint = pick( s->wid->sizeHint() );
 	    a[i].maximumSize = pick( s->wid->maximumSize() );
-	    a[i].empty = FALSE;
+	    a[i].empty = false;
 	} else { //proportional
 	    a[i].stretch = s->sizer;
 	    a[i].maximumSize = pick( s->wid->maximumSize() );
 	    a[i].sizeHint = a[i].minimumSize = pick( minSize(s->wid) );
-	    a[i].empty = FALSE;
+	    a[i].empty = false;
 	}
     }
 
@@ -922,7 +922,7 @@ void KDGanttMinimizeSplitter::recalc( bool update )
     int maxt = TQWIDGETSIZE_MAX;
     int mint = fi;
     int n = data->list.count();
-    bool first = TRUE;
+    bool first = true;
     /*
       The splitter before a hidden widget is always hidden.
       The splitter before the first visible widget is hidden.
@@ -938,15 +938,15 @@ void KDGanttMinimizeSplitter::recalc( bool update )
 		else
 		    p->wid->show(); //may trigger new recalc
 	    if ( !s->wid->isHidden() )
-		first = FALSE;
+		first = false;
 	}
     }
 
-    bool empty=TRUE;
+    bool empty=true;
     for ( int j = 0; j< n; j++ ) {
 	TQSplitterLayoutStruct *s = data->list.at(j);
 	if ( !s->wid->isHidden() ) {
-	    empty = FALSE;
+	    empty = false;
 	    if ( s->isSplitter ) {
 		minl += s->sizer;
 		maxl += s->sizer;
@@ -975,7 +975,7 @@ void KDGanttMinimizeSplitter::recalc( bool update )
     if ( maxt < mint )
 	maxt = mint;
 
-    if ( orient == Qt::Horizontal ) {
+    if ( orient == TQt::Horizontal ) {
 	setMaximumSize( maxl, maxt );
 	setMinimumSize( minl, mint );
     } else {
@@ -1003,13 +1003,13 @@ void KDGanttMinimizeSplitter::setResizeMode( TQWidget *w, ResizeMode mode )
 	}
 	s = data->list.next();
     }
-    s = addWidget( w, TRUE );
+    s = addWidget( w, true );
     s->mode = mode;
 }
 
 
 /*!
-  Returns TRUE if opaque resize is on; otherwise returns FALSE.
+  Returns true if opaque resize is on; otherwise returns false.
 
   \sa setOpaqueResize()
 */
@@ -1021,7 +1021,7 @@ bool KDGanttMinimizeSplitter::opaqueResize() const
 
 
 /*!
-    If \a on is TRUE then opaque resizing is turned on; otherwise
+    If \a on is true then opaque resizing is turned on; otherwise
     opaque resizing is turned off.
   Opaque resizing is initially turned off.
 
@@ -1041,11 +1041,11 @@ void KDGanttMinimizeSplitter::setOpaqueResize( bool on )
 void KDGanttMinimizeSplitter::moveToFirst( TQWidget *w )
 {
     processChildEvents();
-    bool found = FALSE;
+    bool found = false;
     TQSplitterLayoutStruct *s = data->list.first();
     while ( s ) {
 	if ( s->wid == w  ) {
-	    found = TRUE;
+	    found = true;
 	    TQSplitterLayoutStruct *p = data->list.prev();
 	    if ( p ) { // not already at first place
 		data->list.take(); //take p
@@ -1058,7 +1058,7 @@ void KDGanttMinimizeSplitter::moveToFirst( TQWidget *w )
 	s = data->list.next();
     }
      if ( !found )
-	addWidget( w, TRUE );
+	addWidget( w, true );
      recalcId();
 }
 
@@ -1070,11 +1070,11 @@ void KDGanttMinimizeSplitter::moveToFirst( TQWidget *w )
 void KDGanttMinimizeSplitter::moveToLast( TQWidget *w )
 {
     processChildEvents();
-    bool found = FALSE;
+    bool found = false;
     TQSplitterLayoutStruct *s = data->list.first();
     while ( s ) {
 	if ( s->wid == w  ) {
-	    found = TRUE;
+	    found = true;
 	    data->list.take(); // take s
 	    TQSplitterLayoutStruct *p = data->list.current();
 	    if ( p ) { // the splitter handle after s
@@ -1127,7 +1127,7 @@ TQSize KDGanttMinimizeSplitter::sizeHint() const
 	    }
 	}
     }
-    return orientation() == Qt::Horizontal ? TQSize( l, t ) : TQSize( t, l );
+    return orientation() == TQt::Horizontal ? TQSize( l, t ) : TQSize( t, l );
 }
 
 
@@ -1157,7 +1157,7 @@ TQSize KDGanttMinimizeSplitter::minimumSizeHint() const
 	    }
 	}
     }
-    return orientation() == Qt::Horizontal ? TQSize( l, t ) : TQSize( t, l );
+    return orientation() == TQt::Horizontal ? TQSize( l, t ) : TQSize( t, l );
 }
 
 
@@ -1179,7 +1179,7 @@ void KDGanttMinimizeSplitter::storeSizes()
 #if 0 // ### remove this code ASAP
 
 /*!
-  Hides \a w if \a hide is TRUE and updates the splitter.
+  Hides \a w if \a hide is true and updates the splitter.
 
   \warning Due to a limitation in the current implementation,
   calling TQWidget::hide() will not work.
@@ -1201,7 +1201,7 @@ void KDGanttMinimizeSplitter::setHidden( TQWidget *w, bool hide )
 	w->hide();
     else
 	w->show();
-    recalc( TRUE );
+    recalc( true );
 }
 
 
@@ -1219,7 +1219,7 @@ bool KDGanttMinimizeSplitter::isHidden( TQWidget *w ) const
     else
 	tqWarning( "KDGanttMinimizeSplitter::isHidden(), unknown widget" );
 #endif
-    return FALSE;
+    return false;
 }
 #endif
 
@@ -1358,12 +1358,12 @@ void kdganttGeomCalc( TQMemArray<TQLayoutStruct> &chain, int start, int count, i
     int sumStretch = 0;
     int spacerCount = 0;
 
-    bool wannaGrow = FALSE; // anyone who really wants to grow?
-    //    bool canShrink = FALSE; // anyone who could be persuaded to shrink?
+    bool wannaGrow = false; // anyone who really wants to grow?
+    //    bool canShrink = false; // anyone who could be persuaded to shrink?
 
     int i;
     for ( i = start; i < start + count; i++ ) {
-	chain[i].done = FALSE;
+	chain[i].done = false;
 	cHint += chain[i].sizeHint;
 	cMin += chain[i].minimumSize;
 	cMax += chain[i].maximumSize;
@@ -1380,7 +1380,7 @@ void kdganttGeomCalc( TQMemArray<TQLayoutStruct> &chain, int start, int count, i
 	//	tqDebug("not enough space");
 	for ( i = start; i < start+count; i++ ) {
 	    chain[i].size = chain[i].minimumSize;
-	    chain[i].done = TRUE;
+	    chain[i].done = true;
 	}
     } else if ( space < cHint + spacerCount*spacer ) {
 	// Less space than sizeHint, but more than minimum.
@@ -1393,7 +1393,7 @@ void kdganttGeomCalc( TQMemArray<TQLayoutStruct> &chain, int start, int count, i
 	for ( i = start; i < start+count; i++ ) {
 	    if ( !chain[i].done && chain[i].minimumSize >= chain[i].sizeHint) {
 		chain[i].size = chain[i].sizeHint;
-		chain[i].done = TRUE;
+		chain[i].done = true;
 		space_left -= chain[i].sizeHint;
 		// sumStretch -= chain[i].stretch;
 		n--;
@@ -1401,7 +1401,7 @@ void kdganttGeomCalc( TQMemArray<TQLayoutStruct> &chain, int start, int count, i
 	}
 	bool finished = n == 0;
 	while ( !finished ) {
-	    finished = TRUE;
+	    finished = true;
 	    fixed fp_over = toFixed( overdraft );
 	    fixed fp_w = 0;
 
@@ -1416,9 +1416,9 @@ void kdganttGeomCalc( TQMemArray<TQLayoutStruct> &chain, int start, int count, i
 		chain[i].size = chain[i].sizeHint - w;
 		fp_w -= toFixed( w ); //give the difference to the next
 		if ( chain[i].size < chain[i].minimumSize ) {
-		    chain[i].done = TRUE;
+		    chain[i].done = true;
 		    chain[i].size = chain[i].minimumSize;
-		    finished = FALSE;
+		    finished = false;
 		    overdraft -= chain[i].sizeHint - chain[i].minimumSize;
 		    // sumStretch -= chain[i].stretch;
 		    n--;
@@ -1434,7 +1434,7 @@ void kdganttGeomCalc( TQMemArray<TQLayoutStruct> &chain, int start, int count, i
 	    if ( !chain[i].done && (chain[i].maximumSize <= chain[i].sizeHint
 				    || wannaGrow && !chain[i].expansive) ) {
 		chain[i].size = chain[i].sizeHint;
-		chain[i].done = TRUE;
+		chain[i].done = true;
 		space_left -= chain[i].sizeHint;
 		sumStretch -= chain[i].stretch;
 		n--;
@@ -1479,7 +1479,7 @@ void kdganttGeomCalc( TQMemArray<TQLayoutStruct> &chain, int start, int count, i
 		    if ( !chain[i].done &&
 			 chain[i].size < chain[i].sizeHint ) {
 			chain[i].size = chain[i].sizeHint;
-			chain[i].done = TRUE;
+			chain[i].done = true;
 			space_left -= chain[i].sizeHint;
 			sumStretch -= chain[i].stretch;
 			n--;
@@ -1492,7 +1492,7 @@ void kdganttGeomCalc( TQMemArray<TQLayoutStruct> &chain, int start, int count, i
 		    if ( !chain[i].done &&
 			 chain[i].size > chain[i].maximumSize ) {
 			chain[i].size = chain[i].maximumSize;
-			chain[i].done = TRUE;
+			chain[i].done = true;
 			space_left -= chain[i].maximumSize;
 			sumStretch -= chain[i].stretch;
 			n--;
@@ -1531,7 +1531,7 @@ void kdganttGeomCalc( TQMemArray<TQLayoutStruct> &chain, int start, int count, i
 */
 
 /*!
-  \fn Qt::Orientation KDGanttMinimizeSplitter::orientation() const
+  \fn TQt::Orientation KDGanttMinimizeSplitter::orientation() const
 
   Returns the orientation of the splitter.
 */
