@@ -268,7 +268,7 @@ void KDGanttViewTaskLink::showMe( bool visible )
     TQPen p;
     TQBrush b;
     p.setWidth(wid);
-    b.setStyle(Qt::SolidPattern);
+    b.setStyle(TQt::SolidPattern);
     if (ishighlighted) {
         b.setColor(myColorHL);
         p.setColor(myColorHL);
@@ -333,7 +333,7 @@ void KDGanttViewTaskLink::showMeType( bool visible )
     TQPen p;
     TQBrush b;
     p.setWidth(wid);
-    b.setStyle(Qt::SolidPattern);
+    b.setStyle(TQt::SolidPattern);
     if (ishighlighted) {
         b.setColor(myColorHL);
         p.setColor(myColorHL);
