@@ -33,7 +33,7 @@ namespace KMail {
 
 class ConfigureDialog : public KCMultiDialog
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -78,7 +78,7 @@ private:
  * takes care of that.
  */
 class AccountUpdater : public TQObject {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     AccountUpdater(KMail::ImapAccountBase *account);
