@@ -17,7 +17,7 @@
 #include <tdelistview.h>
 #include <tdecmodule.h>
 #include <tdelocale.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 class TQPushButton;
 class TQLabel;
@@ -266,7 +266,7 @@ private:
 //
 //
 
-class KDE_EXPORT IdentityPage : public ConfigModule {
+class TDE_EXPORT IdentityPage : public ConfigModule {
   TQ_OBJECT
   
 public:
@@ -400,7 +400,7 @@ private:
   TQValueList< ModifiedAccountsType* >  mModifiedAccounts;
 };
 
-class KDE_EXPORT AccountsPage : public ConfigModuleWithTabs {
+class TDE_EXPORT AccountsPage : public ConfigModuleWithTabs {
   TQ_OBJECT
   
 public:
@@ -579,7 +579,7 @@ private: // data
   TQButtonGroup *mSystemTrayGroup;
 };
 
-class KDE_EXPORT AppearancePage : public ConfigModuleWithTabs {
+class TDE_EXPORT AppearancePage : public ConfigModuleWithTabs {
   TQ_OBJECT
   
 public:
@@ -808,7 +808,7 @@ private:
   SimpleStringListEditor *mAttachWordsListEditor;
 };
 
-class KDE_EXPORT ComposerPage : public ConfigModuleWithTabs {
+class TDE_EXPORT ComposerPage : public ConfigModuleWithTabs {
   TQ_OBJECT
   
 public:
@@ -959,7 +959,7 @@ private:
   Kleo::BackendConfigWidget * mBackendConfig;
 };
 
-class KDE_EXPORT SecurityPage : public ConfigModuleWithTabs {
+class TDE_EXPORT SecurityPage : public ConfigModuleWithTabs {
   TQ_OBJECT
   
 public:
@@ -1064,7 +1064,7 @@ private:
   TQCheckBox* mAutomaticSending;
 };
 
-class KDE_EXPORT MiscPage : public ConfigModuleWithTabs {
+class TDE_EXPORT MiscPage : public ConfigModuleWithTabs {
   TQ_OBJECT
   
 public:
