@@ -645,7 +645,7 @@ namespace KMail {
 				
 				// kdDebug() << "FancyHeaderStyle::format() local zone offset (in minutes): " << lzone << endl;
 				
-				TQTime currTime = TQTime::currentTime( Qt::UTC );
+				TQTime currTime = TQTime::currentTime( TQt::UTC );
 				
 				// kdDebug() << "FancyHeaderStyle::format() current time: " << currTime << endl;
 				
