@@ -67,7 +67,7 @@ namespace KMail {
       @author Marc Mutz <mutz@kde.org>
   **/
   class IdentityListView : public TDEListView {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     IdentityListView( TQWidget * parent=0, const char * name=0 );
