@@ -39,7 +39,7 @@ class FolderStorage;
 //-----------------------------------------------------------------------------
 class KMAcctImap: public KMail::ImapAccountBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   friend class KMail::ImapJob;
 
