@@ -88,7 +88,7 @@ KMFolderDialog::KMFolderDialog(KMFolder *aFolder, KMFolderDir *aFolderDir,
 			       const TQString& aName):
   KDialogBase( KDialogBase::Tabbed,
                aCap, KDialogBase::Ok|KDialogBase::Cancel,
-               KDialogBase::Ok, aParent, "KMFolderDialog", TRUE ),
+               KDialogBase::Ok, aParent, "KMFolderDialog", true ),
   mFolder( aFolder ),
   mFolderDir( aFolderDir ),
   mParentFolder( 0 ),
@@ -149,12 +149,12 @@ KMFolderDialog::KMFolderDialog(KMFolder *aFolder, KMFolderDir *aFolderDir,
 
 void KMFolderDialog::addTab( FolderDiaTab* tab )
 {
-  connect( tab, TQT_SIGNAL( readyForAccept() ),
-           this, TQT_SLOT( slotReadyForAccept() ) );
-  connect( tab, TQT_SIGNAL( cancelAccept() ),
-           this, TQT_SLOT( slotCancelAccept() ) );
-  //connect( tab, TQT_SIGNAL(changed( bool )),
-  //         this, TQT_SLOT(slotChanged( bool )) );
+  connect( tab, TQ_SIGNAL( readyForAccept() ),
+           this, TQ_SLOT( slotReadyForAccept() ) );
+  connect( tab, TQ_SIGNAL( cancelAccept() ),
+           this, TQ_SLOT( slotCancelAccept() ) );
+  //connect( tab, TQ_SIGNAL(changed( bool )),
+  //         this, TQ_SLOT(slotChanged( bool )) );
   mTabs.append( tab );
 }
 
@@ -343,8 +343,8 @@ KMail::FolderDiaGeneralTab::FolderDiaGeneralTab( KMFolderDialog* dlg,
     }
     label->setBuddy( mNameEdit );
     hl->addWidget( mNameEdit );
-    connect( mNameEdit, TQT_SIGNAL( textChanged( const TQString & ) ),
-                    this, TQT_SLOT( slotFolderNameChanged( const TQString & ) ) );
+    connect( mNameEdit, TQ_SIGNAL( textChanged( const TQString & ) ),
+                    this, TQ_SLOT( slotFolderNameChanged( const TQString & ) ) );
 
 
     //start icons group
@@ -388,17 +388,17 @@ KMail::FolderDiaGeneralTab::FolderDiaGeneralTab( KMFolderDialog* dlg,
     ihl->addWidget( mUnreadIconButton );
     ihl->addStretch( 1 );
 
-    connect( mIconsCheckBox, TQT_SIGNAL(toggled(bool)),
-                    mNormalIconButton, TQT_SLOT(setEnabled(bool)) );
-    connect( mIconsCheckBox, TQT_SIGNAL(toggled(bool)),
-                    mUnreadIconButton, TQT_SLOT(setEnabled(bool)) );
-    connect( mIconsCheckBox, TQT_SIGNAL(toggled(bool)),
-                    mNormalIconLabel, TQT_SLOT(setEnabled(bool)) );
-    connect( mIconsCheckBox, TQT_SIGNAL(toggled(bool)),
-                    mUnreadIconLabel, TQT_SLOT(setEnabled(bool)) );
+    connect( mIconsCheckBox, TQ_SIGNAL(toggled(bool)),
+                    mNormalIconButton, TQ_SLOT(setEnabled(bool)) );
+    connect( mIconsCheckBox, TQ_SIGNAL(toggled(bool)),
+                    mUnreadIconButton, TQ_SLOT(setEnabled(bool)) );
+    connect( mIconsCheckBox, TQ_SIGNAL(toggled(bool)),
+                    mNormalIconLabel, TQ_SLOT(setEnabled(bool)) );
+    connect( mIconsCheckBox, TQ_SIGNAL(toggled(bool)),
+                    mUnreadIconLabel, TQ_SLOT(setEnabled(bool)) );
 
-    connect( mNormalIconButton, TQT_SIGNAL(iconChanged(TQString)),
-                    this, TQT_SLOT(slotChangeIcon(TQString)) );
+    connect( mNormalIconButton, TQ_SIGNAL(iconChanged(TQString)),
+                    this, TQ_SLOT(slotChangeIcon(TQString)) );
 
     //end icons group
     addLine( this, topLayout);
@@ -510,8 +510,8 @@ KMail::FolderDiaGeneralTab::FolderDiaGeneralTab( KMFolderDialog* dlg,
     mContentsComboBox->insertItem( i18n( "Journal" ) );
     if ( mDlg->folder() )
       mContentsComboBox->setCurrentItem( mDlg->folder()->storage()->contentsType() );
-    connect ( mContentsComboBox, TQT_SIGNAL ( activated( int ) ),
-              this, TQT_SLOT( slotFolderContentsSelectionChanged( int ) ) );
+    connect ( mContentsComboBox, TQ_SIGNAL ( activated( int ) ),
+              this, TQ_SLOT( slotFolderContentsSelectionChanged( int ) ) );
     if ( mDlg->folder()->isReadOnly() || mIsResourceFolder )
       mContentsComboBox->setEnabled( false );
   } else {
@@ -816,18 +816,18 @@ KMail::FolderDiaTemplatesTab::FolderDiaTemplatesTab( KMFolderDialog* dlg,
   mCopyGlobal->setEnabled( false );
   btns->addWidget( mCopyGlobal );
 
-  connect( mCustom, TQT_SIGNAL(toggled(bool)),
-        mWidget, TQT_SLOT(setEnabled(bool)) );
-  connect( mCustom, TQT_SIGNAL(toggled(bool)),
-        mCopyGlobal, TQT_SLOT(setEnabled(bool)) );
+  connect( mCustom, TQ_SIGNAL(toggled(bool)),
+        mWidget, TQ_SLOT(setEnabled(bool)) );
+  connect( mCustom, TQ_SIGNAL(toggled(bool)),
+        mCopyGlobal, TQ_SLOT(setEnabled(bool)) );
 
-  connect( mCopyGlobal, TQT_SIGNAL(clicked()),
-        this, TQT_SLOT(slotCopyGlobal()) );
+  connect( mCopyGlobal, TQ_SIGNAL(clicked()),
+        this, TQ_SLOT(slotCopyGlobal()) );
 
   initializeWithValuesFromFolder( mDlg->folder() );
 
-  connect( mWidget, TQT_SIGNAL( changed() ),
-           this, TQT_SLOT( slotEmitChanged( void ) ) );
+  connect( mWidget, TQ_SIGNAL( changed() ),
+           this, TQ_SLOT( slotEmitChanged( void ) ) );
 }
 
 void FolderDiaTemplatesTab::load()
