@@ -137,9 +137,9 @@ public:
   void setContentId( const TQCString & aStr ) { mContentId = aStr; }
 
   /** Set the 'Content-Type' by mime-magic from the contents of the body.
-    If autoDecode is TRUE the decoded body will be used for mime type
+    If autoDecode is true the decoded body will be used for mime type
     determination (this does not change the body itself). */
-  void magicSetType(bool autoDecode=TRUE);
+  void magicSetType(bool autoDecode=true);
 
   /** Get or set a custom content type parameter, consisting of an attribute
     name and a corresponding value. */
