@@ -116,17 +116,17 @@ void KMSearchRuleWidget::initWidget()
 
   RuleWidgetHandlerManager::instance()->createWidgets( mFunctionStack,
                                                        mValueStack,
-                                                       TQT_TQOBJECT(this) );
+                                                       this );
 
   // redirect focus to the header field combo box
   setFocusProxy( mRuleField );
 
-  connect( mRuleField, TQT_SIGNAL( activated( const TQString & ) ),
-	   this, TQT_SLOT( slotRuleFieldChanged( const TQString & ) ) );
-  connect( mRuleField, TQT_SIGNAL( textChanged( const TQString & ) ),
-	   this, TQT_SLOT( slotRuleFieldChanged( const TQString & ) ) );
-  connect( mRuleField, TQT_SIGNAL( textChanged( const TQString & ) ),
-           this, TQT_SIGNAL( fieldChanged( const TQString & ) ) );
+  connect( mRuleField, TQ_SIGNAL( activated( const TQString & ) ),
+	   this, TQ_SLOT( slotRuleFieldChanged( const TQString & ) ) );
+  connect( mRuleField, TQ_SIGNAL( textChanged( const TQString & ) ),
+	   this, TQ_SLOT( slotRuleFieldChanged( const TQString & ) ) );
+  connect( mRuleField, TQ_SIGNAL( textChanged( const TQString & ) ),
+           this, TQ_SIGNAL( fieldChanged( const TQString & ) ) );
 }
 
 void KMSearchRuleWidget::setRule( KMSearchRule *aRule )
@@ -391,14 +391,14 @@ void KMSearchRuleWidgetLister::regenerateRuleListFromWidgets()
 //=============================================================================
 
 KMSearchPatternEdit::KMSearchPatternEdit(TQWidget *parent, const char *name, bool headersOnly, bool absoluteDates )
-  : TQGroupBox( 1/*columns*/, Qt::Horizontal, parent, name )
+  : TQGroupBox( 1/*columns*/, TQt::Horizontal, parent, name )
 {
   setTitle( i18n("Search Criteria") );
   initLayout( headersOnly, absoluteDates );
 }
 
 KMSearchPatternEdit::KMSearchPatternEdit(const TQString & title, TQWidget *parent, const char *name, bool headersOnly, bool absoluteDates)
-  : TQGroupBox( 1/*column*/, Qt::Horizontal, title, parent, name )
+  : TQGroupBox( 1/*column*/, TQt::Horizontal, title, parent, name )
 {
   initLayout( headersOnly, absoluteDates );
 }
@@ -426,15 +426,15 @@ void KMSearchPatternEdit::initLayout(bool headersOnly, bool absoluteDates)
   mRuleLister->slotClear();
 
   //------------connect a few signals
-  connect( bg, TQT_SIGNAL(clicked(int)),
-	   this, TQT_SLOT(slotRadioClicked(int)) );
+  connect( bg, TQ_SIGNAL(clicked(int)),
+	   this, TQ_SLOT(slotRadioClicked(int)) );
 
   KMSearchRuleWidget *srw = (KMSearchRuleWidget*)mRuleLister->mWidgetList.first();
   if ( srw ) {
-    connect( srw, TQT_SIGNAL(fieldChanged(const TQString &)),
-	     this, TQT_SLOT(slotAutoNameHack()) );
-    connect( srw, TQT_SIGNAL(contentsChanged(const TQString &)),
-	     this, TQT_SLOT(slotAutoNameHack()) );
+    connect( srw, TQ_SIGNAL(fieldChanged(const TQString &)),
+	     this, TQ_SLOT(slotAutoNameHack()) );
+    connect( srw, TQ_SIGNAL(contentsChanged(const TQString &)),
+	     this, TQ_SLOT(slotAutoNameHack()) );
   } else
     kdDebug(5006) << "KMSearchPatternEdit: no first KMSearchRuleWidget, though slotClear() has been called!" << endl;
 }
