@@ -231,8 +231,8 @@ bool KMSender::doSendQueued( const TQString &customTransport )
   for( int i = 0 ; i<mTotalMessages ; ++i )
       mTotalBytes += mOutboxFolder->getMsgBase(i)->msgSize();
 
-  connect( mOutboxFolder, TQT_SIGNAL(msgAdded(int)),
-           this, TQT_SLOT(outboxMsgAdded(int)) );
+  connect( mOutboxFolder, TQ_SIGNAL(msgAdded(int)),
+           this, TQ_SLOT(outboxMsgAdded(int)) );
   mCurrentMsg = 0;
 
   mSentFolder = kmkernel->sentFolder();
@@ -472,8 +472,8 @@ void KMSender::doSendMsg()
       i18n( "Sending messages" ),
       i18n("Initiating sender process..."),
       true );
-    connect( mProgressItem, TQT_SIGNAL(progressItemCanceled(KPIM::ProgressItem*)),
-             this, TQT_SLOT( slotAbortSend() ) );
+    connect( mProgressItem, TQ_SIGNAL(progressItemCanceled(KPIM::ProgressItem*)),
+             this, TQ_SLOT( slotAbortSend() ) );
     kapp->ref();
     mSendInProgress = true;
   }
@@ -520,8 +520,8 @@ void KMSender::doSendMsg()
     if (!mSendProc)
       sendProcStarted(false);
     else {
-      connect(mSendProc, TQT_SIGNAL(idle()), TQT_SLOT(slotIdle()));
-      connect(mSendProc, TQT_SIGNAL(started(bool)), TQT_SLOT(sendProcStarted(bool)));
+      connect(mSendProc, TQ_SIGNAL(idle()), TQ_SLOT(slotIdle()));
+      connect(mSendProc, TQ_SIGNAL(started(bool)), TQ_SLOT(sendProcStarted(bool)));
 
       // Run the precommand if there is one
       if ( !mTransportInfo->precommand.isEmpty() ) {
@@ -541,8 +541,8 @@ void KMSender::doSendMsg()
 bool KMSender::runPrecommand( const TQString & cmd ) {
   setStatusMsg( i18n("Executing precommand %1").arg( cmd ) );
   mPrecommand = new KMPrecommand( cmd );
-  connect( mPrecommand, TQT_SIGNAL(finished(bool)),
-           TQT_SLOT(slotPrecommandFinished(bool)) );
+  connect( mPrecommand, TQ_SIGNAL(finished(bool)),
+           TQ_SLOT(slotPrecommandFinished(bool)) );
   if ( !mPrecommand->start() ) {
     delete mPrecommand; mPrecommand = 0;
     return false;
@@ -644,8 +644,8 @@ void KMSender::cleanup(void)
     mSentFolder = 0;
   }
   if ( mOutboxFolder ) {
-    disconnect( mOutboxFolder, TQT_SIGNAL(msgAdded(int)),
-                this, TQT_SLOT(outboxMsgAdded(int)) );
+    disconnect( mOutboxFolder, TQ_SIGNAL(msgAdded(int)),
+                this, TQ_SLOT(outboxMsgAdded(int)) );
     mOutboxFolder->close("dosendoutbox");
     if ( mOutboxFolder->count( true ) == 0 ) {
       mOutboxFolder->expunge();
@@ -947,12 +947,12 @@ bool KMSendSendmail::doStart() {
   {
     mMailerProc = new TDEProcess;
     assert(mMailerProc != 0);
-    connect(mMailerProc,TQT_SIGNAL(processExited(TDEProcess*)),
-	    this, TQT_SLOT(sendmailExited(TDEProcess*)));
-    connect(mMailerProc,TQT_SIGNAL(wroteStdin(TDEProcess*)),
-	    this, TQT_SLOT(wroteStdin(TDEProcess*)));
-    connect(mMailerProc,TQT_SIGNAL(receivedStderr(TDEProcess*,char*,int)),
-	    this, TQT_SLOT(receivedStderr(TDEProcess*, char*, int)));
+    connect(mMailerProc,TQ_SIGNAL(processExited(TDEProcess*)),
+	    this, TQ_SLOT(sendmailExited(TDEProcess*)));
+    connect(mMailerProc,TQ_SIGNAL(wroteStdin(TDEProcess*)),
+	    this, TQ_SLOT(wroteStdin(TDEProcess*)));
+    connect(mMailerProc,TQ_SIGNAL(receivedStderr(TDEProcess*,char*,int)),
+	    this, TQ_SLOT(receivedStderr(TDEProcess*, char*, int)));
   }
   return true;
 }
@@ -1046,8 +1046,8 @@ KMSendSMTP::KMSendSMTP(KMSender *sender)
     mJob(0),
     mSlave(0)
 {
-  TDEIO::Scheduler::connect(TQT_SIGNAL(slaveError(TDEIO::Slave *, int,
-    const TQString &)), this, TQT_SLOT(slaveError(TDEIO::Slave *, int,
+  TDEIO::Scheduler::connect(TQ_SIGNAL(slaveError(TDEIO::Slave *, int,
+    const TQString &)), this, TQ_SLOT(slaveError(TDEIO::Slave *, int,
     const TQString &)));
 }
 
@@ -1154,9 +1154,9 @@ bool KMSendSMTP::doSend( const TQString & sender, const TQStringList & to, const
   }
   mJob->addMetaData( "lf2crlf+dotstuff", "slave" );
   TDEIO::Scheduler::assignJobToSlave(mSlave, mJob);
-  connect(mJob, TQT_SIGNAL(result(TDEIO::Job *)), this, TQT_SLOT(result(TDEIO::Job *)));
-  connect(mJob, TQT_SIGNAL(dataReq(TDEIO::Job *, TQByteArray &)),
-          this, TQT_SLOT(dataReq(TDEIO::Job *, TQByteArray &)));
+  connect(mJob, TQ_SIGNAL(result(TDEIO::Job *)), this, TQ_SLOT(result(TDEIO::Job *)));
+  connect(mJob, TQ_SIGNAL(dataReq(TDEIO::Job *, TQByteArray &)),
+          this, TQ_SLOT(dataReq(TDEIO::Job *, TQByteArray &)));
   mSendOk = true;
   mInProcess = true;
   return true;
