@@ -63,7 +63,7 @@ KMServerTest::KMServerTest( const TQString & protocol, const TQString & host, in
 //-----------------------------------------------------------------------------
 KMServerTest::~KMServerTest()
 {
-  if (mJob) mJob->kill(TRUE);
+  if (mJob) mJob->kill(true);
 }
 
 
