@@ -74,7 +74,7 @@ void MaildirJob::setParentFolder( const KMFolderMaildir* parent )
 //-----------------------------------------------------------------------------
 void MaildirJob::execute()
 {
-  TQTimer::singleShot( 0, this, TQT_SLOT(startJob()) );
+  TQTimer::singleShot( 0, this, TQ_SLOT(startJob()) );
 }
 
 //-----------------------------------------------------------------------------
