@@ -58,8 +58,8 @@ MailSourceViewer::MailSourceViewer( TQWidget *parent, const char *name )
 {
   setWFlags( WDestructiveClose );
   TQAccel *accel = new TQAccel( this, "browser close-accel" );
-  accel->connectItem( accel->insertItem( TQt::Key_Escape ), this , TQT_SLOT( close() ));
-  accel->connectItem( accel->insertItem( TQt::Key_W+CTRL ), this , TQT_SLOT( close() ));
+  accel->connectItem( accel->insertItem( TQt::Key_Escape ), this , TQ_SLOT( close() ));
+  accel->connectItem( accel->insertItem( TQt::Key_W+CTRL ), this , TQ_SLOT( close() ));
   setWordWrap( KTextBrowser::NoWrap );
   KWin::setIcons(winId(), kapp->icon(), kapp->miniIcon());
 }
