@@ -67,7 +67,7 @@ MboxJob::~MboxJob()
 void
 MboxJob::execute()
 {
-  TQTimer::singleShot( 0, this, TQT_SLOT(startJob()) );
+  TQTimer::singleShot( 0, this, TQ_SLOT(startJob()) );
 }
 
 //-----------------------------------------------------------------------------
