@@ -40,7 +40,7 @@ namespace KMail {
 
 class MboxJob : public FolderJob
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   friend class ::KMFolderMbox;
 public:
