@@ -85,19 +85,19 @@ namespace KMail {
     TQWidgetStack * widgetStack = new TQWidgetStack( this );
     widgetStack->setEnabled( false ); // since !mEnableCheck->isChecked()
     vlay->addWidget( widgetStack, 1 );
-    connect( mSourceCombo, TQT_SIGNAL(highlighted(int)),
-	     widgetStack, TQT_SLOT(raiseWidget(int)) );
+    connect( mSourceCombo, TQ_SIGNAL(highlighted(int)),
+	     widgetStack, TQ_SLOT(raiseWidget(int)) );
     // connects for the enabling of the widgets depending on
     // signatureEnabled:
-    connect( mEnableCheck, TQT_SIGNAL(toggled(bool)),
-	     mSourceCombo, TQT_SLOT(setEnabled(bool)) );
-    connect( mEnableCheck, TQT_SIGNAL(toggled(bool)),
-	     widgetStack, TQT_SLOT(setEnabled(bool)) );
-    connect( mEnableCheck, TQT_SIGNAL(toggled(bool)),
-	     label, TQT_SLOT(setEnabled(bool)) );
+    connect( mEnableCheck, TQ_SIGNAL(toggled(bool)),
+	     mSourceCombo, TQ_SLOT(setEnabled(bool)) );
+    connect( mEnableCheck, TQ_SIGNAL(toggled(bool)),
+	     widgetStack, TQ_SLOT(setEnabled(bool)) );
+    connect( mEnableCheck, TQ_SIGNAL(toggled(bool)),
+	     label, TQ_SLOT(setEnabled(bool)) );
     // The focus might be still in the widget that is disabled
-    connect( mEnableCheck, TQT_SIGNAL(clicked()),
-	     mEnableCheck, TQT_SLOT(setFocus()) );
+    connect( mEnableCheck, TQ_SIGNAL(clicked()),
+	     mEnableCheck, TQ_SLOT(setFocus()) );
 
     int pageno = 0;
     // page 0: input field for direct entering:
@@ -126,11 +126,11 @@ namespace KMail {
 				 i18n("S&pecify file:"), page ) );
     hlay->addWidget( mFileRequester, 1 );
     mFileRequester->button()->setAutoDefault( false );
-    connect( mFileRequester, TQT_SIGNAL(textChanged(const TQString &)),
-	     this, TQT_SLOT(slotEnableEditButton(const TQString &)) );
+    connect( mFileRequester, TQ_SIGNAL(textChanged(const TQString &)),
+	     this, TQ_SLOT(slotEnableEditButton(const TQString &)) );
     mEditButton = new TQPushButton( i18n("Edit &File"), page );
     TQWhatsThis::add(mEditButton, i18n("Opens the specified file in a text editor."));
-    connect( mEditButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotEdit()) );
+    connect( mEditButton, TQ_SIGNAL(clicked()), TQ_SLOT(slotEdit()) );
     mEditButton->setAutoDefault( false );
     mEditButton->setEnabled( false ); // initially nothing to edit
     hlay->addWidget( mEditButton );
