@@ -8,7 +8,7 @@ class TQListBox;
 
 class TDEListBoxDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
