@@ -13,7 +13,7 @@ class KMDict;
 
 class MessageDictTester : public KUnitTest::SlotTester
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public slots:
