@@ -11,7 +11,7 @@
 
 class UtilTester : public KUnitTest::SlotTester
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public slots:
