@@ -9,7 +9,7 @@
 
 #include "kmobileiface.h"
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 class TDEConfig;
 class KMobileItem;
 
@@ -20,9 +20,9 @@ class KMobileItem;
  * @author Helge Deller <deller@kde.org>
  * @version 0.1
  */
-class KDE_EXPORT KMobileView : public TQIconView, public kmobileIface
+class TDE_EXPORT KMobileView : public TQIconView, public kmobileIface
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMobileView(TQWidget *parent, TDEConfig *_config);
