@@ -13,7 +13,7 @@ class KMobilePrefPageTwo;
 
 class KMobilePreferences : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMobilePreferences();
@@ -25,7 +25,7 @@ private:
 
 class KMobilePrefPageOne : public TQFrame
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMobilePrefPageOne(TQWidget *parent = 0);
@@ -33,7 +33,7 @@ public:
 
 class KMobilePrefPageTwo : public TQFrame
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMobilePrefPageTwo(TQWidget *parent = 0);
