@@ -27,7 +27,7 @@ class TDEAction;
 
 class SystemTray : public KSystemTray
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
