@@ -65,7 +65,7 @@ void KNArticleFactory::createPosting(KNNntpAccount *a)
 
   KNComposer *c = new KNComposer( art, TQString(), sig, TQString(), true );
   mCompList.append( c );
-  connect(c, TQT_SIGNAL(composerDone(KNComposer*)), this, TQT_SLOT(slotComposerDone(KNComposer*)));
+  connect(c, TQ_SIGNAL(composerDone(KNComposer*)), this, TQ_SLOT(slotComposerDone(KNComposer*)));
   c->show();
 }
 
@@ -94,7 +94,7 @@ void KNArticleFactory::createPosting(KNGroup *g)
 
   KNComposer *c=new KNComposer(art, TQString(), sig, TQString(), true);
   mCompList.append( c );
-  connect(c, TQT_SIGNAL(composerDone(KNComposer*)), this, TQT_SLOT(slotComposerDone(KNComposer*)));
+  connect(c, TQ_SIGNAL(composerDone(KNComposer*)), this, TQ_SLOT(slotComposerDone(KNComposer*)));
   c->show();
 }
 
@@ -264,7 +264,7 @@ void KNArticleFactory::createReply(KNRemoteArticle *a, TQString selectedText, bo
   //open composer
   KNComposer *c=new KNComposer(art, quoted, sig, notRewraped, true, authorDislikesMailCopies, authorWantsMailCopies);
   mCompList.append( c );
-  connect(c, TQT_SIGNAL(composerDone(KNComposer*)), this, TQT_SLOT(slotComposerDone(KNComposer*)));
+  connect(c, TQ_SIGNAL(composerDone(KNComposer*)), this, TQ_SLOT(slotComposerDone(KNComposer*)));
   c->show();
 }
 
@@ -349,7 +349,7 @@ void KNArticleFactory::createForward(KNArticle *a)
   //open composer
   KNComposer *c=new KNComposer(art, fwd, sig, TQString(), true);
   mCompList.append( c );
-  connect(c, TQT_SIGNAL(composerDone(KNComposer*)), this, TQT_SLOT(slotComposerDone(KNComposer*)));
+  connect(c, TQ_SIGNAL(composerDone(KNComposer*)), this, TQ_SLOT(slotComposerDone(KNComposer*)));
   c->show();
 }
 
@@ -500,7 +500,7 @@ void KNArticleFactory::createSupersede(KNArticle *a)
   //open composer
   KNComposer *c=new KNComposer(art, text, sig);
   mCompList.append( c );
-  connect(c, TQT_SIGNAL(composerDone(KNComposer*)), this, TQT_SLOT(slotComposerDone(KNComposer*)));
+  connect(c, TQ_SIGNAL(composerDone(KNComposer*)), this, TQ_SLOT(slotComposerDone(KNComposer*)));
   c->show();
 }
 
@@ -525,7 +525,7 @@ void KNArticleFactory::createMail(KMime::Headers::AddressField *address)
   //open composer
   KNComposer *c=new KNComposer(art, TQString(), sig, TQString(), true);
   mCompList.append( c );
-  connect(c, TQT_SIGNAL(composerDone(KNComposer*)), this, TQT_SLOT(slotComposerDone(KNComposer*)));
+  connect(c, TQ_SIGNAL(composerDone(KNComposer*)), this, TQ_SLOT(slotComposerDone(KNComposer*)));
   c->show();
 }
 
@@ -604,7 +604,7 @@ void KNArticleFactory::edit(KNLocalArticle *a)
                                 .arg(id->getSigGeneratorStdErr()));
 
   mCompList.append( com );
-  connect(com, TQT_SIGNAL(composerDone(KNComposer*)), this, TQT_SLOT(slotComposerDone(KNComposer*)));
+  connect(com, TQ_SIGNAL(composerDone(KNComposer*)), this, TQ_SLOT(slotComposerDone(KNComposer*)));
   com->show();
 }
 
@@ -990,7 +990,7 @@ void KNArticleFactory::showSendErrorDialog()
 {
   if(!s_endErrDlg) {
     s_endErrDlg=new KNSendErrorDialog();
-    connect(s_endErrDlg, TQT_SIGNAL(closeClicked()), this, TQT_SLOT(slotSendErrorDialogDone()));
+    connect(s_endErrDlg, TQ_SIGNAL(closeClicked()), this, TQ_SLOT(slotSendErrorDialogDone()));
   }
   s_endErrDlg->show();
 }
@@ -1075,7 +1075,7 @@ KNSendErrorDialog::KNSendErrorDialog()
   j_obs=new KNDialogListBox(true, page);
   e_rror=new TQLabel(TQString(), page);
 
-  connect(j_obs, TQT_SIGNAL(highlighted(int)), this, TQT_SLOT(slotHighlighted(int)));
+  connect(j_obs, TQ_SIGNAL(highlighted(int)), this, TQ_SLOT(slotHighlighted(int)));
 
   KNHelper::restoreWindowSize("sendDlg", this, TQSize(320,250));
 }
