@@ -78,7 +78,7 @@ TQPopupMenu *KNLineEdit::createPopupMenu()
 
     menu->insertSeparator();
     menu->insertItem( i18n( "Edit Recent Addresses..." ),
-                      this, TQT_SLOT( editRecentAddresses() ) );
+                      this, TQ_SLOT( editRecentAddresses() ) );
 
     return menu;
 }
@@ -183,9 +183,9 @@ KNComposer::KNComposer(KNLocalArticle *a, const TQString &text, const TQString &
   v_iew=new ComposerView(this);
   setCentralWidget(v_iew);
 
-  connect(v_iew->c_ancelEditorBtn, TQT_SIGNAL(clicked()), TQT_SLOT(slotCancelEditor()));
-  connect(v_iew->e_dit, TQT_SIGNAL(sigDragEnterEvent(TQDragEnterEvent *)), TQT_SLOT(slotDragEnterEvent(TQDragEnterEvent *)));
-  connect(v_iew->e_dit, TQT_SIGNAL(sigDropEvent(TQDropEvent *)), TQT_SLOT(slotDropEvent(TQDropEvent *)));
+  connect(v_iew->c_ancelEditorBtn, TQ_SIGNAL(clicked()), TQ_SLOT(slotCancelEditor()));
+  connect(v_iew->e_dit, TQ_SIGNAL(sigDragEnterEvent(TQDragEnterEvent *)), TQ_SLOT(slotDragEnterEvent(TQDragEnterEvent *)));
+  connect(v_iew->e_dit, TQ_SIGNAL(sigDropEvent(TQDropEvent *)), TQ_SLOT(slotDropEvent(TQDropEvent *)));
 
   //statusbar
   KStatusBar *sb=statusBar();
@@ -199,128 +199,128 @@ KNComposer::KNComposer(KNLocalArticle *a, const TQString &text, const TQString &
   sb->setItemAlignment (4,AlignCenter | AlignVCenter);
   sb->insertItem(TQString(), 5,0);                 // line
   sb->setItemAlignment (5,AlignCenter | AlignVCenter);
-  connect(v_iew->e_dit, TQT_SIGNAL(CursorPositionChanged()), TQT_SLOT(slotUpdateCursorPos()));
-  connect(v_iew->e_dit, TQT_SIGNAL(toggle_overwrite_signal()), TQT_SLOT(slotUpdateStatusBar()));
+  connect(v_iew->e_dit, TQ_SIGNAL(CursorPositionChanged()), TQ_SLOT(slotUpdateCursorPos()));
+  connect(v_iew->e_dit, TQ_SIGNAL(toggle_overwrite_signal()), TQ_SLOT(slotUpdateStatusBar()));
 
   //------------------------------- <Actions> --------------------------------------
 
   //file menu
-  new TDEAction(i18n("&Send Now"),"mail-send", CTRL + Key_Return , TQT_TQOBJECT(this),
-    TQT_SLOT(slotSendNow()), actionCollection(), "send_now");
+  new TDEAction(i18n("&Send Now"),"mail-send", CTRL + Key_Return , this,
+    TQ_SLOT(slotSendNow()), actionCollection(), "send_now");
 
-  new TDEAction(i18n("Send &Later"), "queue", 0, TQT_TQOBJECT(this),
-    TQT_SLOT(slotSendLater()), actionCollection(), "send_later");
+  new TDEAction(i18n("Send &Later"), "queue", 0, this,
+    TQ_SLOT(slotSendLater()), actionCollection(), "send_later");
 
-  new TDEAction(i18n("Save as &Draft"),"document-save", 0 , TQT_TQOBJECT(this),
-    TQT_SLOT(slotSaveAsDraft()), actionCollection(), "save_as_draft");
+  new TDEAction(i18n("Save as &Draft"),"document-save", 0 , this,
+    TQ_SLOT(slotSaveAsDraft()), actionCollection(), "save_as_draft");
 
-  new TDEAction(i18n("D&elete"),"edit-delete", 0 , TQT_TQOBJECT(this),
-    TQT_SLOT(slotArtDelete()), actionCollection(), "art_delete");
+  new TDEAction(i18n("D&elete"),"edit-delete", 0 , this,
+    TQ_SLOT(slotArtDelete()), actionCollection(), "art_delete");
 
-  KStdAction::close(TQT_TQOBJECT(this), TQT_SLOT(close()),actionCollection());
+  KStdAction::close(this, TQ_SLOT(close()),actionCollection());
 
   //edit menu
-  KStdAction::undo(TQT_TQOBJECT(this), TQT_SLOT(slotUndo()), actionCollection());
-  KStdAction::redo(TQT_TQOBJECT(this), TQT_SLOT(slotRedo()), actionCollection());
+  KStdAction::undo(this, TQ_SLOT(slotUndo()), actionCollection());
+  KStdAction::redo(this, TQ_SLOT(slotRedo()), actionCollection());
 
-  KStdAction::cut(TQT_TQOBJECT(this), TQT_SLOT(slotCut()), actionCollection());
+  KStdAction::cut(this, TQ_SLOT(slotCut()), actionCollection());
 
 
-  KStdAction::copy(TQT_TQOBJECT(this), TQT_SLOT(slotCopy()), actionCollection());
+  KStdAction::copy(this, TQ_SLOT(slotCopy()), actionCollection());
 
-  KStdAction::pasteText(TQT_TQOBJECT(this), TQT_SLOT(slotPaste()), actionCollection());
+  KStdAction::pasteText(this, TQ_SLOT(slotPaste()), actionCollection());
 
-  new TDEAction(i18n("Paste as &Quotation"), 0, TQT_TQOBJECT(v_iew->e_dit),
-                   TQT_SLOT(slotPasteAsQuotation()), actionCollection(), "paste_quoted");
+  new TDEAction(i18n("Paste as &Quotation"), 0, v_iew->e_dit,
+                   TQ_SLOT(slotPasteAsQuotation()), actionCollection(), "paste_quoted");
 
-  KStdAction::selectAll(TQT_TQOBJECT(this), TQT_SLOT(slotSelectAll()), actionCollection());
+  KStdAction::selectAll(this, TQ_SLOT(slotSelectAll()), actionCollection());
 
-  KStdAction::find(TQT_TQOBJECT(v_iew->e_dit), TQT_SLOT(slotFind()), actionCollection());
-  KStdAction::findNext(TQT_TQOBJECT(v_iew->e_dit), TQT_SLOT(slotSearchAgain()), actionCollection());
+  KStdAction::find(v_iew->e_dit, TQ_SLOT(slotFind()), actionCollection());
+  KStdAction::findNext(v_iew->e_dit, TQ_SLOT(slotSearchAgain()), actionCollection());
 
-  KStdAction::replace(TQT_TQOBJECT(v_iew->e_dit), TQT_SLOT(slotReplace()), actionCollection());
+  KStdAction::replace(v_iew->e_dit, TQ_SLOT(slotReplace()), actionCollection());
 
   //attach menu
-  new TDEAction(i18n("Append &Signature"), 0 , TQT_TQOBJECT(this), TQT_SLOT(slotAppendSig()),
+  new TDEAction(i18n("Append &Signature"), 0 , this, TQ_SLOT(slotAppendSig()),
                    actionCollection(), "append_signature");
 
-  new TDEAction(i18n("&Insert File..."), 0, TQT_TQOBJECT(this), TQT_SLOT(slotInsertFile()),
+  new TDEAction(i18n("&Insert File..."), 0, this, TQ_SLOT(slotInsertFile()),
                    actionCollection(), "insert_file");
 
-  new TDEAction(i18n("Insert File (in a &box)..."), 0, TQT_TQOBJECT(this), TQT_SLOT(slotInsertFileBoxed()),
+  new TDEAction(i18n("Insert File (in a &box)..."), 0, this, TQ_SLOT(slotInsertFileBoxed()),
                    actionCollection(), "insert_file_boxed");
 
-  new TDEAction(i18n("Attach &File..."), "attach", 0, TQT_TQOBJECT(this), TQT_SLOT(slotAttachFile()),
+  new TDEAction(i18n("Attach &File..."), "attach", 0, this, TQ_SLOT(slotAttachFile()),
                    actionCollection(), "attach_file");
 
   a_ctPGPsign = new TDEToggleAction(i18n("Sign Article with &PGP"),
 		   "signature", 0,
                    actionCollection(), "sign_article");
 
-  a_ctRemoveAttachment = new TDEAction(i18n("&Remove"), 0, TQT_TQOBJECT(this),
-                                    TQT_SLOT(slotRemoveAttachment()), actionCollection(), "remove_attachment");
+  a_ctRemoveAttachment = new TDEAction(i18n("&Remove"), 0, this,
+                                    TQ_SLOT(slotRemoveAttachment()), actionCollection(), "remove_attachment");
 
-  a_ctAttachmentProperties  = new TDEAction(i18n("&Properties"), 0, TQT_TQOBJECT(this),
-                                          TQT_SLOT(slotAttachmentProperties()), actionCollection(), "attachment_properties");
+  a_ctAttachmentProperties  = new TDEAction(i18n("&Properties"), 0, this,
+                                          TQ_SLOT(slotAttachmentProperties()), actionCollection(), "attachment_properties");
 
   //options menu
 
-  a_ctDoPost = new TDEToggleAction(i18n("Send &News Article"), "document-new", 0 , TQT_TQOBJECT(this),
-                   TQT_SLOT(slotToggleDoPost()), actionCollection(), "send_news");
+  a_ctDoPost = new TDEToggleAction(i18n("Send &News Article"), "document-new", 0 , this,
+                   TQ_SLOT(slotToggleDoPost()), actionCollection(), "send_news");
 
-  a_ctDoMail = new TDEToggleAction(i18n("Send E&mail"), "mail_generic" , 0 , TQT_TQOBJECT(this),
-                   TQT_SLOT(slotToggleDoMail()), actionCollection(), "send_mail");
+  a_ctDoMail = new TDEToggleAction(i18n("Send E&mail"), "mail_generic" , 0 , this,
+                   TQ_SLOT(slotToggleDoMail()), actionCollection(), "send_mail");
 
   a_ctSetCharset = new TDESelectAction(i18n("Set &Charset"), 0, actionCollection(), "set_charset");
   a_ctSetCharset->setItems(knGlobals.configManager()->postNewsTechnical()->composerCharsets());
   a_ctSetCharset->setShortcutConfigurable(false);
-  connect(a_ctSetCharset, TQT_SIGNAL(activated(const TQString&)),
-  this, TQT_SLOT(slotSetCharset(const TQString&)));
+  connect(a_ctSetCharset, TQ_SIGNAL(activated(const TQString&)),
+  this, TQ_SLOT(slotSetCharset(const TQString&)));
 
-  a_ctSetCharsetKeyb = new TDEAction(i18n("Set Charset"), 0, TQT_TQOBJECT(this),
-                                   TQT_SLOT(slotSetCharsetKeyboard()), actionCollection(), "set_charset_keyboard");
+  a_ctSetCharsetKeyb = new TDEAction(i18n("Set Charset"), 0, this,
+                                   TQ_SLOT(slotSetCharsetKeyboard()), actionCollection(), "set_charset_keyboard");
 
 
-  a_ctWordWrap  = new TDEToggleAction(i18n("&Word Wrap"), 0 , TQT_TQOBJECT(this),
-                      TQT_SLOT(slotToggleWordWrap()), actionCollection(), "toggle_wordwrap");
+  a_ctWordWrap  = new TDEToggleAction(i18n("&Word Wrap"), 0 , this,
+                      TQ_SLOT(slotToggleWordWrap()), actionCollection(), "toggle_wordwrap");
 
   //tools menu
 
-  new TDEAction(i18n("Add &Quote Characters"), 0, TQT_TQOBJECT(v_iew->e_dit),
-              TQT_SLOT(slotAddQuotes()), actionCollection(), "tools_quote");
+  new TDEAction(i18n("Add &Quote Characters"), 0, v_iew->e_dit,
+              TQ_SLOT(slotAddQuotes()), actionCollection(), "tools_quote");
 
-  new TDEAction(i18n("&Remove Quote Characters"), 0, TQT_TQOBJECT(v_iew->e_dit),
-              TQT_SLOT(slotRemoveQuotes()), actionCollection(), "tools_unquote");
+  new TDEAction(i18n("&Remove Quote Characters"), 0, v_iew->e_dit,
+              TQ_SLOT(slotRemoveQuotes()), actionCollection(), "tools_unquote");
 
-  new TDEAction(i18n("Add &Box"), 0, TQT_TQOBJECT(v_iew->e_dit),
-              TQT_SLOT(slotAddBox()), actionCollection(), "tools_box");
+  new TDEAction(i18n("Add &Box"), 0, v_iew->e_dit,
+              TQ_SLOT(slotAddBox()), actionCollection(), "tools_box");
 
-  new TDEAction(i18n("Re&move Box"), 0, TQT_TQOBJECT(v_iew->e_dit),
-              TQT_SLOT(slotRemoveBox()), actionCollection(), "tools_unbox");
+  new TDEAction(i18n("Re&move Box"), 0, v_iew->e_dit,
+              TQ_SLOT(slotRemoveBox()), actionCollection(), "tools_unbox");
 
-  TDEAction *undoRewrap = new TDEAction(i18n("Get &Original Text (not re-wrapped)"), 0, TQT_TQOBJECT(this),
-                                    TQT_SLOT(slotUndoRewrap()), actionCollection(), "tools_undoRewrap");
+  TDEAction *undoRewrap = new TDEAction(i18n("Get &Original Text (not re-wrapped)"), 0, this,
+                                    TQ_SLOT(slotUndoRewrap()), actionCollection(), "tools_undoRewrap");
   undoRewrap->setEnabled(!u_nwraped.isNull());
 
-  TDEAction *rot13 = new TDEAction(i18n("S&cramble (Rot 13)"), "encrypted", 0, TQT_TQOBJECT(v_iew->e_dit),
-                               TQT_SLOT(slotRot13()), actionCollection(), "tools_rot13");
+  TDEAction *rot13 = new TDEAction(i18n("S&cramble (Rot 13)"), "encrypted", 0, v_iew->e_dit,
+                               TQ_SLOT(slotRot13()), actionCollection(), "tools_rot13");
   rot13->setEnabled(false);
-  connect(v_iew->e_dit, TQT_SIGNAL(copyAvailable(bool)), rot13, TQT_SLOT(setEnabled(bool)));
+  connect(v_iew->e_dit, TQ_SIGNAL(copyAvailable(bool)), rot13, TQ_SLOT(setEnabled(bool)));
 
-  a_ctExternalEditor = new TDEAction(i18n("Start &External Editor"), "system-run", 0, TQT_TQOBJECT(this),
-                       TQT_SLOT(slotExternalEditor()), actionCollection(), "external_editor");
+  a_ctExternalEditor = new TDEAction(i18n("Start &External Editor"), "system-run", 0, this,
+                       TQ_SLOT(slotExternalEditor()), actionCollection(), "external_editor");
 
-  a_ctSpellCheck = KStdAction::spelling (TQT_TQOBJECT(this), TQT_SLOT(slotSpellcheck()), actionCollection());
+  a_ctSpellCheck = KStdAction::spelling (this, TQ_SLOT(slotSpellcheck()), actionCollection());
 
   //settings menu
   createStandardStatusBarAction();
   setStandardToolBarMenuEnabled(true);
 
-  KStdAction::keyBindings(TQT_TQOBJECT(this), TQT_SLOT(slotConfKeys()), actionCollection());
+  KStdAction::keyBindings(this, TQ_SLOT(slotConfKeys()), actionCollection());
 
-  KStdAction::configureToolbars(TQT_TQOBJECT(this), TQT_SLOT(slotConfToolbar()), actionCollection());
+  KStdAction::configureToolbars(this, TQ_SLOT(slotConfToolbar()), actionCollection());
 
-  KStdAction::preferences(TQT_TQOBJECT(knGlobals.top), TQT_SLOT(slotSettings()), actionCollection());
+  KStdAction::preferences(knGlobals.top, TQ_SLOT(slotSettings()), actionCollection());
 
   a_ccel=new TDEAccel(this);
   a_ctSetCharsetKeyb->plugAccel(a_ccel);
@@ -420,7 +420,7 @@ int KNComposer::listOfResultOfCheckWord( const TQStringList & lst , const TQStri
             {
                 TDEAction * act = new TDEAction( *it );
 
-                connect( act, TQT_SIGNAL(activated()), v_iew->e_dit, TQT_SLOT(slotCorrectWord()) );
+                connect( act, TQ_SIGNAL(activated()), v_iew->e_dit, TQ_SLOT(slotCorrectWord()) );
                 m_listAction.append( act );
             }
         }
@@ -437,7 +437,7 @@ void KNComposer::slotUndo()
 
     if (fw->inherits("KEdit"))
         ((TQMultiLineEdit*)fw)->undo();
-    else if (fw->inherits(TQLINEEDIT_OBJECT_NAME_STRING))
+    else if (fw->inherits("TQLineEdit"))
         ((TQLineEdit*)fw)->undo();
 }
 
@@ -448,7 +448,7 @@ void KNComposer::slotRedo()
 
     if (fw->inherits("KEdit"))
         ((TQMultiLineEdit*)fw)->redo();
-    else if (fw->inherits(TQLINEEDIT_OBJECT_NAME_STRING))
+    else if (fw->inherits("TQLineEdit"))
         ((TQLineEdit*)fw)->redo();
 }
 
@@ -459,7 +459,7 @@ void KNComposer::slotCut()
 
   if (fw->inherits("KEdit"))
     ((TQMultiLineEdit*)fw)->cut();
-  else if (fw->inherits(TQLINEEDIT_OBJECT_NAME_STRING))
+  else if (fw->inherits("TQLineEdit"))
     ((TQLineEdit*)fw)->cut();
   else kdDebug(5003) << "wrong focus widget" << endl;
 }
@@ -471,7 +471,7 @@ void KNComposer::slotCopy()
 
   if (fw->inherits("KEdit"))
     ((TQMultiLineEdit*)fw)->copy();
-  else if (fw->inherits(TQLINEEDIT_OBJECT_NAME_STRING))
+  else if (fw->inherits("TQLineEdit"))
     ((TQLineEdit*)fw)->copy();
   else kdDebug(5003) << "wrong focus widget" << endl;
 
@@ -485,7 +485,7 @@ void KNComposer::slotPaste()
 
   if (fw->inherits("KEdit"))
     ((TQMultiLineEdit*)fw)->paste();
-  else if (fw->inherits(TQLINEEDIT_OBJECT_NAME_STRING))
+  else if (fw->inherits("TQLineEdit"))
     ((TQLineEdit*)fw)->paste();
   else kdDebug(5003) << "wrong focus widget" << endl;
 }
@@ -495,9 +495,9 @@ void KNComposer::slotSelectAll()
   TQWidget* fw = focusWidget();
   if (!fw) return;
 
-  if (fw->inherits(TQLINEEDIT_OBJECT_NAME_STRING))
+  if (fw->inherits("TQLineEdit"))
       ((TQLineEdit*)fw)->selectAll();
-  else if (fw->inherits(TQMULTILINEEDIT_OBJECT_NAME_STRING))
+  else if (fw->inherits("TQMultiLineEdit"))
     ((TQMultiLineEdit*)fw)->selectAll();
 }
 
@@ -1302,7 +1302,7 @@ void KNComposer::slotExternalEditor()
   if(!filenameAdded)    // no %f in the editor command
     (*e_xternalEditor) << e_ditorTempfile->name();
 
-  connect(e_xternalEditor, TQT_SIGNAL(processExited(TDEProcess *)),this, TQT_SLOT(slotEditorFinished(TDEProcess *)));
+  connect(e_xternalEditor, TQ_SIGNAL(processExited(TDEProcess *)),this, TQ_SLOT(slotEditorFinished(TDEProcess *)));
   if(!e_xternalEditor->start()) {
     KMessageBox::error(this, i18n("Unable to start external editor.\nPlease check your configuration in the settings dialog."));
     delete e_xternalEditor;
@@ -1327,17 +1327,17 @@ void KNComposer::slotSpellcheck()
   a_ctExternalEditor->setEnabled(false);
   a_ctSpellCheck->setEnabled(false);
 
-  s_pellChecker = new KSpell(TQT_TQWIDGET(this), i18n("Spellcheck"), TQT_TQOBJECT(this), TQT_SLOT(slotSpellStarted(KSpell *)));
+  s_pellChecker = new KSpell(this, i18n("Spellcheck"), this, TQ_SLOT(slotSpellStarted(KSpell *)));
   TQStringList l = KSpellingHighlighter::personalWords();
   for ( TQStringList::Iterator it = l.begin(); it != l.end(); ++it ) {
       s_pellChecker->addPersonal( *it );
   }
-  connect(s_pellChecker, TQT_SIGNAL(death()), this, TQT_SLOT(slotSpellFinished()));
-  connect(s_pellChecker, TQT_SIGNAL(done(const TQString&)), this, TQT_SLOT(slotSpellDone(const TQString&)));
-  connect(s_pellChecker, TQT_SIGNAL(misspelling (const TQString &, const TQStringList &, unsigned int)),
-          this, TQT_SLOT(slotMisspelling (const TQString &, const TQStringList &, unsigned int)));
-  connect(s_pellChecker, TQT_SIGNAL(corrected (const TQString &, const TQString &, unsigned int)),
-          this, TQT_SLOT(slotCorrected (const TQString &, const TQString &, unsigned int)));
+  connect(s_pellChecker, TQ_SIGNAL(death()), this, TQ_SLOT(slotSpellFinished()));
+  connect(s_pellChecker, TQ_SIGNAL(done(const TQString&)), this, TQ_SLOT(slotSpellDone(const TQString&)));
+  connect(s_pellChecker, TQ_SIGNAL(misspelling (const TQString &, const TQStringList &, unsigned int)),
+          this, TQ_SLOT(slotMisspelling (const TQString &, const TQStringList &, unsigned int)));
+  connect(s_pellChecker, TQ_SIGNAL(corrected (const TQString &, const TQString &, unsigned int)),
+          this, TQ_SLOT(slotCorrected (const TQString &, const TQString &, unsigned int)));
 }
 
 
@@ -1401,7 +1401,7 @@ void KNComposer::slotConfToolbar()
   conf->setGroup("composerWindow_options");
   saveMainWindowSettings(conf);
   KEditToolbar dlg(guiFactory(),this);
-  connect(&dlg,TQT_SIGNAL( newToolbarConfig() ), this, TQT_SLOT( slotNewToolbarConfig() ));
+  connect(&dlg,TQ_SIGNAL( newToolbarConfig() ), this, TQ_SLOT( slotNewToolbarConfig() ));
   dlg.exec();
 }
 
@@ -1508,10 +1508,10 @@ void KNComposer::slotGroupsBtnClicked()
 
   KNGroupSelectDialog *dlg=new KNGroupSelectDialog(this, nntp, v_iew->g_roups->text().remove(TQRegExp("\\s")));
 
-  connect(dlg, TQT_SIGNAL(loadList(KNNntpAccount*)),
-    knGlobals.groupManager(), TQT_SLOT(slotLoadGroupList(KNNntpAccount*)));
-  connect(knGlobals.groupManager(), TQT_SIGNAL(newListReady(KNGroupListData*)),
-    dlg, TQT_SLOT(slotReceiveList(KNGroupListData*)));
+  connect(dlg, TQ_SIGNAL(loadList(KNNntpAccount*)),
+    knGlobals.groupManager(), TQ_SLOT(slotLoadGroupList(KNNntpAccount*)));
+  connect(knGlobals.groupManager(), TQ_SIGNAL(newListReady(KNGroupListData*)),
+    dlg, TQ_SLOT(slotReceiveList(KNGroupListData*)));
 
   if(dlg->exec())
     v_iew->g_roups->setText(dlg->selectedGroups());
@@ -1725,7 +1725,7 @@ TQPopupMenu * KNComposer::popupMenu( const TQString& name )
 
 
 KNComposer::ComposerView::ComposerView(KNComposer *composer, const char *n)
-  : TQSplitter(Qt::Vertical, composer, n), a_ttWidget(0), a_ttView(0), v_iewOpen(false)
+  : TQSplitter(TQt::Vertical, composer, n), a_ttWidget(0), a_ttView(0), v_iewOpen(false)
 {
   TQWidget *main=new TQWidget(this);
 
@@ -1744,7 +1744,7 @@ KNComposer::ComposerView::ComposerView(KNComposer *composer, const char *n)
   hdrL->addWidget(l_to, 0,0);
   hdrL->addWidget(t_o, 0,1);
   hdrL->addWidget(t_oBtn, 0,2);
-  connect(t_oBtn, TQT_SIGNAL(clicked()), parent(), TQT_SLOT(slotToBtnClicked()));
+  connect(t_oBtn, TQ_SIGNAL(clicked()), parent(), TQ_SLOT(slotToBtnClicked()));
 
   //Newsgroups
   g_roups=new KNLineEdit(this, false, hdrFrame);
@@ -1755,9 +1755,9 @@ KNComposer::ComposerView::ComposerView(KNComposer *composer, const char *n)
   hdrL->addWidget(l_groups, 1,0);
   hdrL->addWidget(g_roups, 1,1);
   hdrL->addWidget(g_roupsBtn, 1,2);
-  connect(g_roups, TQT_SIGNAL(textChanged(const TQString&)),
-          parent(), TQT_SLOT(slotGroupsChanged(const TQString&)));
-  connect(g_roupsBtn, TQT_SIGNAL(clicked()), parent(), TQT_SLOT(slotGroupsBtnClicked()));
+  connect(g_roups, TQ_SIGNAL(textChanged(const TQString&)),
+          parent(), TQ_SLOT(slotGroupsChanged(const TQString&)));
+  connect(g_roupsBtn, TQ_SIGNAL(clicked()), parent(), TQ_SLOT(slotGroupsBtnClicked()));
 
   //Followup-To
   f_up2=new KComboBox(true, hdrFrame);
@@ -1772,8 +1772,8 @@ KNComposer::ComposerView::ComposerView(KNComposer *composer, const char *n)
   TQLabel *l=new TQLabel(s_ubject, i18n("S&ubject:"), hdrFrame);
   hdrL->addWidget(l, 3,0);
   hdrL->addMultiCellWidget(s_ubject, 3,3, 1,2);
-  connect(s_ubject, TQT_SIGNAL(textChanged(const TQString&)),
-          parent(), TQT_SLOT(slotSubjectChanged(const TQString&)));
+  connect(s_ubject, TQ_SIGNAL(textChanged(const TQString&)),
+          parent(), TQ_SLOT(slotSubjectChanged(const TQString&)));
 
   //Editor
   e_dit=new Editor(this, composer, main);
@@ -1793,12 +1793,12 @@ KNComposer::ComposerView::ComposerView(KNComposer *composer, const char *n)
   mSpellChecker = new KDictSpellingHighlighter(e_dit, /*active*/ true, /*autoEnabled*/ true,
                                        /*spellColor*/ config->readColorEntry("NewMessage", &c),
                                        /*colorQuoting*/ true, col1, col2, col3, col4);
-  connect( mSpellChecker, TQT_SIGNAL(newSuggestions(const TQString&, const TQStringList&, unsigned int)), e_dit,
-           TQT_SLOT(slotAddSuggestion(const TQString&, const TQStringList&, unsigned int)) );
+  connect( mSpellChecker, TQ_SIGNAL(newSuggestions(const TQString&, const TQStringList&, unsigned int)), e_dit,
+           TQ_SLOT(slotAddSuggestion(const TQString&, const TQStringList&, unsigned int)) );
 
   TQVBoxLayout *notL=new TQVBoxLayout(e_dit);
   notL->addStretch(1);
-  n_otification=new TQGroupBox(2, Qt::Horizontal, e_dit);
+  n_otification=new TQGroupBox(2, TQt::Horizontal, e_dit);
   l=new TQLabel(i18n("You are currently editing the article body\nin an external editor. To continue, you have\nto close the external editor."), n_otification);
   c_ancelEditorBtn=new TQPushButton(i18n("&Kill External Editor"), n_otification);
   n_otification->setFrameStyle(TQFrame::Panel | TQFrame::Raised);
@@ -1906,33 +1906,33 @@ void KNComposer::ComposerView::showAttachmentView()
     topL->addMultiCellWidget(a_ttView, 0,2, 0,0);
 
     //connections
-    connect(a_ttView, TQT_SIGNAL(currentChanged(TQListViewItem*)),
-            parent(), TQT_SLOT(slotAttachmentSelected(TQListViewItem*)));
-    connect(a_ttView, TQT_SIGNAL(clicked ( TQListViewItem * )),
-            parent(), TQT_SLOT(slotAttachmentSelected(TQListViewItem*)));
+    connect(a_ttView, TQ_SIGNAL(currentChanged(TQListViewItem*)),
+            parent(), TQ_SLOT(slotAttachmentSelected(TQListViewItem*)));
+    connect(a_ttView, TQ_SIGNAL(clicked ( TQListViewItem * )),
+            parent(), TQ_SLOT(slotAttachmentSelected(TQListViewItem*)));
 
-    connect(a_ttView, TQT_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)),
-            parent(), TQT_SLOT(slotAttachmentPopup(TDEListView*, TQListViewItem*, const TQPoint&)));
-    connect(a_ttView, TQT_SIGNAL(delPressed(TQListViewItem*)),
-            parent(), TQT_SLOT(slotAttachmentRemove(TQListViewItem*)));
-    connect(a_ttView, TQT_SIGNAL(doubleClicked(TQListViewItem*)),
-            parent(), TQT_SLOT(slotAttachmentEdit(TQListViewItem*)));
-    connect(a_ttView, TQT_SIGNAL(returnPressed(TQListViewItem*)),
-            parent(), TQT_SLOT(slotAttachmentEdit(TQListViewItem*)));
+    connect(a_ttView, TQ_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)),
+            parent(), TQ_SLOT(slotAttachmentPopup(TDEListView*, TQListViewItem*, const TQPoint&)));
+    connect(a_ttView, TQ_SIGNAL(delPressed(TQListViewItem*)),
+            parent(), TQ_SLOT(slotAttachmentRemove(TQListViewItem*)));
+    connect(a_ttView, TQ_SIGNAL(doubleClicked(TQListViewItem*)),
+            parent(), TQ_SLOT(slotAttachmentEdit(TQListViewItem*)));
+    connect(a_ttView, TQ_SIGNAL(returnPressed(TQListViewItem*)),
+            parent(), TQ_SLOT(slotAttachmentEdit(TQListViewItem*)));
 
     //buttons
     a_ttAddBtn=new TQPushButton(i18n("A&dd..."),a_ttWidget);
-    connect(a_ttAddBtn, TQT_SIGNAL(clicked()), parent(), TQT_SLOT(slotAttachFile()));
+    connect(a_ttAddBtn, TQ_SIGNAL(clicked()), parent(), TQ_SLOT(slotAttachFile()));
     topL->addWidget(a_ttAddBtn, 0,1);
 
     a_ttRemoveBtn=new TQPushButton(i18n("&Remove"), a_ttWidget);
     a_ttRemoveBtn->setEnabled(false);
-    connect(a_ttRemoveBtn, TQT_SIGNAL(clicked()), parent(), TQT_SLOT(slotRemoveAttachment()));
+    connect(a_ttRemoveBtn, TQ_SIGNAL(clicked()), parent(), TQ_SLOT(slotRemoveAttachment()));
     topL->addWidget(a_ttRemoveBtn, 1,1);
 
     a_ttEditBtn=new TQPushButton(i18n("&Properties"), a_ttWidget);
     a_ttEditBtn->setEnabled(false);
-    connect(a_ttEditBtn, TQT_SIGNAL(clicked()), parent(), TQT_SLOT(slotAttachmentProperties()));
+    connect(a_ttEditBtn, TQ_SIGNAL(clicked()), parent(), TQ_SLOT(slotAttachmentProperties()));
     topL->addWidget(a_ttEditBtn, 2,1, TQt::AlignTop);
 
     topL->setRowStretch(2,1);
@@ -2011,7 +2011,7 @@ KNComposer::Editor::~Editor()
 //-----------------------------------------------------------------------------
 bool KNComposer::Editor::eventFilter(TQObject*o, TQEvent* e)
 {
-  if (TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(this))
+  if (o == this)
     KCursor::autoHideEventFilter(o, e);
 
   if (e->type() == TQEvent::KeyPress)
@@ -2398,15 +2398,15 @@ void KNComposer::Editor::contentsContextMenuEvent( TQContextMenuEvent */*e*/ )
     }
     else
     {
-        spell = new KSpell(this, i18n("Spellcheck"), TQT_TQOBJECT(this), TQT_SLOT(slotSpellStarted(KSpell *)));
+        spell = new KSpell(this, i18n("Spellcheck"), this, TQ_SLOT(slotSpellStarted(KSpell *)));
         TQStringList l = KSpellingHighlighter::personalWords();
         for ( TQStringList::Iterator it = l.begin(); it != l.end(); ++it ) {
             spell->addPersonal( *it );
         }
-        connect(spell, TQT_SIGNAL(death()), this, TQT_SLOT(slotSpellFinished()));
-        connect(spell, TQT_SIGNAL(done(const TQString&)), this, TQT_SLOT(slotSpellDone(const TQString&)));
-        connect(spell, TQT_SIGNAL(misspelling (const TQString &, const TQStringList &, unsigned int)),
-                this, TQT_SLOT(slotMisspelling (const TQString &, const TQStringList &, unsigned int)));
+        connect(spell, TQ_SIGNAL(death()), this, TQ_SLOT(slotSpellFinished()));
+        connect(spell, TQ_SIGNAL(done(const TQString&)), this, TQ_SLOT(slotSpellDone(const TQString&)));
+        connect(spell, TQ_SIGNAL(misspelling (const TQString &, const TQStringList &, unsigned int)),
+                this, TQ_SLOT(slotMisspelling (const TQString &, const TQStringList &, unsigned int)));
     }
 }
 
@@ -2600,8 +2600,8 @@ KNComposer::AttachmentPropertiesDlg::AttachmentPropertiesDlg(KNAttachment *a, TQ
   topL->addWidget(mimeGB);
 
   //connections
-  connect(m_imeType, TQT_SIGNAL(textChanged(const TQString&)),
-    this, TQT_SLOT(slotMimeTypeTextChanged(const TQString&)));
+  connect(m_imeType, TQ_SIGNAL(textChanged(const TQString&)),
+    this, TQ_SLOT(slotMimeTypeTextChanged(const TQString&)));
 
   //finish GUI
   setFixedHeight(sizeHint().height());
@@ -2657,5 +2657,3 @@ void KNComposer::AttachmentPropertiesDlg::slotMimeTypeTextChanged(const TQString
 //--------------------------------
 
 #include "kncomposer.moc"
-
-// kate: space-indent on; indent-width 2;
