@@ -26,7 +26,7 @@ class KNRangeFilterWidget;
 
 class KNFilterConfigWidget : public TQTabWidget  {
 
-  Q_OBJECT
+  TQ_OBJECT
   
   
   friend class KNFilterDialog;
