@@ -44,14 +44,14 @@ KNGroupSelectDialog::KNGroupSelectDialog(TQWidget *parent, KNNntpAccount *a, con
     new GroupItem(selView, info);
   }
 
-  connect(selView, TQT_SIGNAL(selectionChanged(TQListViewItem*)),
-    this, TQT_SLOT(slotItemSelected(TQListViewItem*)));
-  connect(groupView, TQT_SIGNAL(selectionChanged(TQListViewItem*)),
-    this, TQT_SLOT(slotItemSelected(TQListViewItem*)));
-  connect(groupView, TQT_SIGNAL(selectionChanged()),
-    this, TQT_SLOT(slotSelectionChanged()));
-  connect(arrowBtn1, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotArrowBtn1()));
-  connect(arrowBtn2, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotArrowBtn2()));
+  connect(selView, TQ_SIGNAL(selectionChanged(TQListViewItem*)),
+    this, TQ_SLOT(slotItemSelected(TQListViewItem*)));
+  connect(groupView, TQ_SIGNAL(selectionChanged(TQListViewItem*)),
+    this, TQ_SLOT(slotItemSelected(TQListViewItem*)));
+  connect(groupView, TQ_SIGNAL(selectionChanged()),
+    this, TQ_SLOT(slotSelectionChanged()));
+  connect(arrowBtn1, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotArrowBtn1()));
+  connect(arrowBtn2, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotArrowBtn2()));
 
   KNHelper::restoreWindowSize("groupSelDlg", this, TQSize(659,364));  // optimized for 800x600
 }
