@@ -27,7 +27,7 @@ class KNArticleFilter;
 
 class KNSearchDialog : public TQDialog {
 
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
