@@ -46,7 +46,7 @@ class Journal;
 
 class KNotesPart : public KParts::ReadOnlyPart, virtual public KNotesIface
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
