@@ -45,11 +45,11 @@
 
 #include "newsfeeds.h"
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 extern "C"
 {
-  KDE_EXPORT TDECModule *create_kontactknt( TQWidget *parent, const char * )
+  TDE_EXPORT TDECModule *create_kontactknt( TQWidget *parent, const char * )
   {
     return new KCMKontactKNT( parent, "kcmkontactknt" );
   }
@@ -80,10 +80,10 @@ NewsEditDialog::NewsEditDialog( const TQString& title, const TQString& url, TQWi
   mTitle->setText( title );
   mURL->setText( url );
   mTitle->setFocus();
-  connect( mTitle, TQT_SIGNAL( textChanged( const TQString& ) ),
-           this, TQT_SLOT( modified() ) );
-  connect( mURL, TQT_SIGNAL( textChanged( const TQString& ) ),
-           this, TQT_SLOT( modified() ) );
+  connect( mTitle, TQ_SIGNAL( textChanged( const TQString& ) ),
+           this, TQ_SLOT( modified() ) );
+  connect( mURL, TQ_SIGNAL( textChanged( const TQString& ) ),
+           this, TQ_SLOT( modified() ) );
 
   modified();
 }
@@ -133,18 +133,18 @@ KCMKontactKNT::KCMKontactKNT( TQWidget *parent, const char *name )
 {
   initGUI();
 
-  connect( mAllNews, TQT_SIGNAL( currentChanged( TQListViewItem* ) ),
-           this, TQT_SLOT( allCurrentChanged( TQListViewItem* ) ) );
-  connect( mSelectedNews, TQT_SIGNAL( selectionChanged( TQListViewItem* ) ),
-           this, TQT_SLOT( selectedChanged( TQListViewItem* ) ) );
+  connect( mAllNews, TQ_SIGNAL( currentChanged( TQListViewItem* ) ),
+           this, TQ_SLOT( allCurrentChanged( TQListViewItem* ) ) );
+  connect( mSelectedNews, TQ_SIGNAL( selectionChanged( TQListViewItem* ) ),
+           this, TQ_SLOT( selectedChanged( TQListViewItem* ) ) );
 
-  connect( mUpdateInterval, TQT_SIGNAL( valueChanged( int ) ), TQT_SLOT( modified() ) );
-  connect( mArticleCount, TQT_SIGNAL( valueChanged( int ) ), TQT_SLOT( modified() ) );
+  connect( mUpdateInterval, TQ_SIGNAL( valueChanged( int ) ), TQ_SLOT( modified() ) );
+  connect( mArticleCount, TQ_SIGNAL( valueChanged( int ) ), TQ_SLOT( modified() ) );
 
-  connect( mAddButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( addNews() ) );
-  connect( mRemoveButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( removeNews() ) );
-  connect( mNewButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( newFeed() ) );
-  connect( mDeleteButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( deleteFeed() ) );
+  connect( mAddButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( addNews() ) );
+  connect( mRemoveButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( removeNews() ) );
+  connect( mNewButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( newFeed() ) );
+  connect( mDeleteButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( deleteFeed() ) );
 
   TDEAcceleratorManager::manage( this );
 
@@ -356,7 +356,7 @@ void KCMKontactKNT::initGUI()
   mSelectedNews->setFullWidth( true );
   layout->addWidget( mSelectedNews, 0, 2 );
 
-  TQGroupBox *box = new TQGroupBox( 0, Qt::Vertical,
+  TQGroupBox *box = new TQGroupBox( 0, TQt::Vertical,
                                   i18n( "News Feed Settings" ), this );
 
   TQGridLayout *boxLayout = new TQGridLayout( box->layout(), 2, 3,
