@@ -26,7 +26,7 @@
 
 class DropWidget : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
