@@ -198,7 +198,7 @@ class KOAgenda : public TQScrollView
     void droppedToDo( Todo*todo, const TQPoint &gpos, bool allDay );
 
     void enableAgendaUpdate( bool enable );
-    void zoomView( const int delta, const TQPoint &pos, const Qt::Orientation );
+    void zoomView( const int delta, const TQPoint &pos, const TQt::Orientation );
 
     void mousePosSignal(const TQPoint &pos);
     void enterAgenda();
