@@ -197,7 +197,7 @@ class KOAgendaView : public KOrg::AgendaView, public KCal::Calendar::Observer
 
     void zoomView( const int delta, const TQPoint &pos,
 
-    const Qt::Orientation orient=Qt::Horizontal );
+    const TQt::Orientation orient=TQt::Horizontal );
 
     void clearTimeSpanSelection();
 
