@@ -125,9 +125,9 @@ void KODayMatrix::setCalendar( Calendar *cal )
   mCalendar->registerObserver( this );
   CalendarResources *calres = dynamic_cast<CalendarResources*>( cal );
   if ( calres ) {
-    connect( calres, TQT_SIGNAL(signalResourceAdded(ResourceCalendar *)), TQT_SLOT(resourcesChanged()) );
-    connect( calres, TQT_SIGNAL(signalResourceModified( ResourceCalendar *)), TQT_SLOT(resourcesChanged()) );
-    connect( calres, TQT_SIGNAL(signalResourceDeleted(ResourceCalendar *)), TQT_SLOT(resourcesChanged()) );
+    connect( calres, TQ_SIGNAL(signalResourceAdded(ResourceCalendar *)), TQ_SLOT(resourcesChanged()) );
+    connect( calres, TQ_SIGNAL(signalResourceModified( ResourceCalendar *)), TQ_SLOT(resourcesChanged()) );
+    connect( calres, TQ_SIGNAL(signalResourceDeleted(ResourceCalendar *)), TQ_SLOT(resourcesChanged()) );
   }
 
   setAcceptDrops( mCalendar );
@@ -725,5 +725,5 @@ TQPair<TQDate,TQDate> KODayMatrix::matrixLimits( const TQDate &month )
     d = d.addDays( -7 ); // Start on the second line
   }
 
-  return tqMakePair( d, d.addDays( NUMDAYS-1 ) );
+  return qMakePair( d, d.addDays( NUMDAYS-1 ) );
 }
