@@ -25,7 +25,7 @@
 #define KOEVENTVIEWERDIALOG_H
 
 #include <kdialogbase.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 #include "koeventviewer.h"
 
 namespace KCal {
@@ -38,7 +38,7 @@ class KOEventViewer;
 /**
   Viewer dialog for events.
 */
-class KDE_EXPORT KOEventViewerDialog : public KDialogBase
+class TDE_EXPORT KOEventViewerDialog : public KDialogBase
 {
     TQ_OBJECT
   
