@@ -299,7 +299,7 @@ void KOTodoListView::contentsMousePressEvent(TQMouseEvent* e)
         treeStepSize() * (i->depth() + (rootIsDecorated() ? 1 : 0)) +
         itemMargin() ||
         p.x() < header()->sectionPos(header()->mapToIndex(0))) {
-      if (e->button()==Qt::LeftButton) {
+      if (e->button()==TQt::LeftButton) {
         mPressPos = e->pos();
         mMousePressed = true;
       }
@@ -424,16 +424,16 @@ KOTodoView::KOTodoView( Calendar *calendar, TQWidget *parent, const char* name)
   mPriority[ mPriorityPopupMenu->insertItem( i18n( "7" ) ) ] = 7;
   mPriority[ mPriorityPopupMenu->insertItem( i18n( "8" ) ) ] = 8;
   mPriority[ mPriorityPopupMenu->insertItem( i18n( "9 (lowest)" ) ) ] = 9;
-  connect( mPriorityPopupMenu, TQT_SIGNAL( activated( int ) ),
-           TQT_SLOT( setNewPriority( int ) ));
+  connect( mPriorityPopupMenu, TQ_SIGNAL( activated( int ) ),
+           TQ_SLOT( setNewPriority( int ) ));
 
   mPercentageCompletedPopupMenu = new TQPopupMenu(this);
   for (int i = 0; i <= 100; i+=10) {
     TQString label = TQString ("%1 %").arg (i);
     mPercentage[mPercentageCompletedPopupMenu->insertItem (label)] = i;
   }
-  connect( mPercentageCompletedPopupMenu, TQT_SIGNAL( activated( int ) ),
-           TQT_SLOT( setNewPercentage( int ) ) );
+  connect( mPercentageCompletedPopupMenu, TQ_SIGNAL( activated( int ) ),
+           TQ_SLOT( setNewPercentage( int ) ) );
 
   mMovePopupMenu = new KDatePickerPopup(
                              KDatePickerPopup::NoDate |
@@ -445,76 +445,76 @@ KOTodoView::KOTodoView( Calendar *calendar, TQWidget *parent, const char* name)
                              KDatePickerPopup::Words );
 
 
-  connect( mMovePopupMenu, TQT_SIGNAL( dateChanged( TQDate )),
-           TQT_SLOT( setNewDate( TQDate ) ) );
-  connect( mCopyPopupMenu, TQT_SIGNAL( dateChanged( TQDate )),
-           TQT_SLOT( copyTodoToDate( TQDate ) ) );
+  connect( mMovePopupMenu, TQ_SIGNAL( dateChanged( TQDate )),
+           TQ_SLOT( setNewDate( TQDate ) ) );
+  connect( mCopyPopupMenu, TQ_SIGNAL( dateChanged( TQDate )),
+           TQ_SLOT( copyTodoToDate( TQDate ) ) );
 
   mItemPopupMenu = new TQPopupMenu(this);
   mItemPopupMenu->insertItem(i18n("&Show"), this,
-                             TQT_SLOT (showTodo()));
+                             TQ_SLOT (showTodo()));
   mItemPopupMenu->insertItem(i18n("&Edit..."), this,
-                             TQT_SLOT (editTodo()), 0, ePopupEdit );
+                             TQ_SLOT (editTodo()), 0, ePopupEdit );
 #ifndef KORG_NOPRINTER
-  mItemPopupMenu->insertItem(KOGlobals::self()->smallIcon("printer"), i18n("&Print..."), this, TQT_SLOT( printTodo() ) );
+  mItemPopupMenu->insertItem(KOGlobals::self()->smallIcon("printer"), i18n("&Print..."), this, TQ_SLOT( printTodo() ) );
 #endif
   mItemPopupMenu->insertItem(KOGlobals::self()->smallIconSet("edit-delete"), i18n("&Delete"), this,
-                             TQT_SLOT (deleteTodo()), 0, ePopupDelete );
+                             TQ_SLOT (deleteTodo()), 0, ePopupDelete );
   mItemPopupMenu->insertSeparator();
   mItemPopupMenu->insertItem(KOGlobals::self()->smallIconSet("todo"), i18n("New &To-do..."), this,
-                             TQT_SLOT (newTodo()) );
+                             TQ_SLOT (newTodo()) );
   mItemPopupMenu->insertItem(i18n("New Su&b-to-do..."), this,
-                             TQT_SLOT (newSubTodo()));
+                             TQ_SLOT (newSubTodo()));
   mItemPopupMenu->insertItem( i18n("&Make this To-do Independent"), this,
-      TQT_SIGNAL( unSubTodoSignal() ), 0, ePopupUnSubTodo );
+      TQ_SIGNAL( unSubTodoSignal() ), 0, ePopupUnSubTodo );
   mItemPopupMenu->insertItem( i18n("Make all Sub-to-dos &Independent"), this,
-      TQT_SIGNAL( unAllSubTodoSignal() ), 0, ePopupUnAllSubTodo );
+      TQ_SIGNAL( unAllSubTodoSignal() ), 0, ePopupUnAllSubTodo );
   mItemPopupMenu->insertSeparator();
   mItemPopupMenu->insertItem( i18n("&Copy To"), mCopyPopupMenu, ePopupCopyTo );
   mItemPopupMenu->insertItem(i18n("&Move To"), mMovePopupMenu, ePopupMoveTo );
   mItemPopupMenu->insertSeparator();
   mItemPopupMenu->insertItem(i18n("delete completed to-dos","Pur&ge Completed"),
-                             this, TQT_SLOT( purgeCompleted() ) );
+                             this, TQ_SLOT( purgeCompleted() ) );
 
-  connect( mMovePopupMenu, TQT_SIGNAL( dateChanged( TQDate ) ),
-           mItemPopupMenu, TQT_SLOT( hide() ) );
-  connect( mCopyPopupMenu, TQT_SIGNAL( dateChanged( TQDate ) ),
-           mItemPopupMenu, TQT_SLOT( hide() ) );
+  connect( mMovePopupMenu, TQ_SIGNAL( dateChanged( TQDate ) ),
+           mItemPopupMenu, TQ_SLOT( hide() ) );
+  connect( mCopyPopupMenu, TQ_SIGNAL( dateChanged( TQDate ) ),
+           mItemPopupMenu, TQ_SLOT( hide() ) );
 
   mPopupMenu = new TQPopupMenu(this);
   mPopupMenu->insertItem(KOGlobals::self()->smallIconSet("todo"), i18n("&New To-do..."), this,
-                         TQT_SLOT(newTodo()) );
+                         TQ_SLOT(newTodo()) );
   mPopupMenu->insertItem(i18n("delete completed to-dos","&Purge Completed"),
-                         this, TQT_SLOT(purgeCompleted()));
+                         this, TQ_SLOT(purgeCompleted()));
 
   mDocPrefs = new DocPrefs( name );
 
   // Double clicking conflicts with opening/closing the subtree
-  connect( mTodoListView, TQT_SIGNAL( doubleClicked( TQListViewItem *,
+  connect( mTodoListView, TQ_SIGNAL( doubleClicked( TQListViewItem *,
                                                  const TQPoint &, int ) ),
-           TQT_SLOT( editItem( TQListViewItem *, const TQPoint &, int ) ) );
-  connect( mTodoListView, TQT_SIGNAL( returnPressed( TQListViewItem * ) ),
-           TQT_SLOT( editItem( TQListViewItem * ) ) );
-  connect( mTodoListView, TQT_SIGNAL( contextMenuRequested( TQListViewItem *,
+           TQ_SLOT( editItem( TQListViewItem *, const TQPoint &, int ) ) );
+  connect( mTodoListView, TQ_SIGNAL( returnPressed( TQListViewItem * ) ),
+           TQ_SLOT( editItem( TQListViewItem * ) ) );
+  connect( mTodoListView, TQ_SIGNAL( contextMenuRequested( TQListViewItem *,
                                                         const TQPoint &, int ) ),
-           TQT_SLOT( popupMenu( TQListViewItem *, const TQPoint &, int ) ) );
-  connect( mTodoListView, TQT_SIGNAL( expanded( TQListViewItem * ) ),
-           TQT_SLOT( itemStateChanged( TQListViewItem * ) ) );
-  connect( mTodoListView, TQT_SIGNAL( collapsed( TQListViewItem * ) ),
-           TQT_SLOT( itemStateChanged( TQListViewItem * ) ) );
+           TQ_SLOT( popupMenu( TQListViewItem *, const TQPoint &, int ) ) );
+  connect( mTodoListView, TQ_SIGNAL( expanded( TQListViewItem * ) ),
+           TQ_SLOT( itemStateChanged( TQListViewItem * ) ) );
+  connect( mTodoListView, TQ_SIGNAL( collapsed( TQListViewItem * ) ),
+           TQ_SLOT( itemStateChanged( TQListViewItem * ) ) );
 
 #if 0
-  connect(mTodoListView,TQT_SIGNAL(selectionChanged(TQListViewItem *)),
-          TQT_SLOT(selectionChanged(TQListViewItem *)));
-  connect(mTodoListView,TQT_SIGNAL(clicked(TQListViewItem *)),
-          TQT_SLOT(selectionChanged(TQListViewItem *)));
-  connect(mTodoListView,TQT_SIGNAL(pressed(TQListViewItem *)),
-          TQT_SLOT(selectionChanged(TQListViewItem *)));
+  connect(mTodoListView,TQ_SIGNAL(selectionChanged(TQListViewItem *)),
+          TQ_SLOT(selectionChanged(TQListViewItem *)));
+  connect(mTodoListView,TQ_SIGNAL(clicked(TQListViewItem *)),
+          TQ_SLOT(selectionChanged(TQListViewItem *)));
+  connect(mTodoListView,TQ_SIGNAL(pressed(TQListViewItem *)),
+          TQ_SLOT(selectionChanged(TQListViewItem *)));
 #endif
-  connect( mTodoListView, TQT_SIGNAL(selectionChanged() ),
-           TQT_SLOT( processSelectionChange() ) );
-  connect( mQuickAdd, TQT_SIGNAL( returnPressed () ),
-           TQT_SLOT( addQuickTodo() ) );
+  connect( mTodoListView, TQ_SIGNAL(selectionChanged() ),
+           TQ_SLOT( processSelectionChange() ) );
+  connect( mQuickAdd, TQ_SIGNAL( returnPressed () ),
+           TQ_SLOT( addQuickTodo() ) );
 
   new KOTodoListViewToolTip( mTodoListView->viewport(), calendar, mTodoListView );
 }
@@ -648,7 +648,7 @@ bool KOTodoView::scheduleRemoveTodoItem( KOTodoViewItem *todoItem )
 {
   if ( todoItem ) {
     mItemsToDelete.append( todoItem );
-    TQTimer::singleShot( 0, this, TQT_SLOT( removeTodoItems() ) );
+    TQTimer::singleShot( 0, this, TQ_SLOT( removeTodoItems() ) );
     return true;
   } else
     return false;
@@ -731,13 +731,13 @@ void KOTodoView::changeIncidenceDisplay(Incidence *incidence, int action)
         }
         break;
       default:
-        TQTimer::singleShot( 0, this, TQT_SLOT( updateView() ) );
+        TQTimer::singleShot( 0, this, TQ_SLOT( updateView() ) );
     }
   } else {
     // use a TQTimer here, because when marking todos finished using
     // the checkbox, this slot gets called, but we cannot update the views
     // because we're still inside KOTodoViewItem::stateChange
-    TQTimer::singleShot(0,this,TQT_SLOT(updateView()));
+    TQTimer::singleShot(0,this,TQ_SLOT(updateView()));
   }
 }
 
@@ -857,7 +857,7 @@ void KOTodoView::printTodo()
 #ifndef KORG_NOPRINTER
   KOCoreHelper helper;
   CalPrinter printer( this, BaseView::calendar(), &helper );
-  connect( this, TQT_SIGNAL(configChanged()), &printer, TQT_SLOT(updateConfig()) );
+  connect( this, TQ_SIGNAL(configChanged()), &printer, TQ_SLOT(updateConfig()) );
 
   Incidence::List selectedIncidences;
   selectedIncidences.append( mActiveItem->todo() );
@@ -1015,8 +1015,8 @@ TQPopupMenu *KOTodoView::getCategoryPopupMenu( KOTodoViewItem *todoItem )
       tempMenu->setItemChecked( index, true );
   }
 
-  connect ( tempMenu, TQT_SIGNAL( activated( int ) ),
-            TQT_SLOT( changedCategories( int ) ) );
+  connect ( tempMenu, TQ_SIGNAL( activated( int ) ),
+            TQ_SLOT( changedCategories( int ) ) );
   return tempMenu;
 }
 
@@ -1065,9 +1065,9 @@ void KOTodoView::itemStateChanged( TQListViewItem *item )
 
 void KOTodoView::setNewPercentageDelayed( KOTodoViewItem *item, int percentage )
 {
-  mPercentChangedMap.append( tqMakePair( item, percentage ) );
+  mPercentChangedMap.append( qMakePair( item, percentage ) );
 
-  TQTimer::singleShot( 0, this, TQT_SLOT( processDelayedNewPercentage() ) );
+  TQTimer::singleShot( 0, this, TQ_SLOT( processDelayedNewPercentage() ) );
 }
 
 void KOTodoView::processDelayedNewPercentage()
