@@ -225,60 +225,60 @@ void KOViewManager::connectView(KOrg::BaseView *view)
   if (!view) return;
 
   // selecting an incidence
-  connect( view, TQT_SIGNAL( incidenceSelected( Incidence *,const TQDate & ) ),
-           mMainView, TQT_SLOT( processMainViewSelection( Incidence *,const TQDate & ) ) );
+  connect( view, TQ_SIGNAL( incidenceSelected( Incidence *,const TQDate & ) ),
+           mMainView, TQ_SLOT( processMainViewSelection( Incidence *,const TQDate & ) ) );
 
   // showing/editing/deleting an incidence. The calendar view takes care of the action.
-  connect( view, TQT_SIGNAL(showIncidenceSignal(Incidence *,const TQDate &)),
-           mMainView, TQT_SLOT(showIncidence(Incidence *,const TQDate &)) );
-  connect( view, TQT_SIGNAL(editIncidenceSignal(Incidence *,const TQDate &)),
-           mMainView, TQT_SLOT(editIncidence(Incidence *,const TQDate &)) );
-  connect( view, TQT_SIGNAL(deleteIncidenceSignal(Incidence *)),
-           mMainView, TQT_SLOT(deleteIncidence(Incidence *)) );
-  connect( view, TQT_SIGNAL(copyIncidenceSignal(Incidence *)),
-           mMainView, TQT_SLOT(copyIncidence(Incidence *)) );
-  connect( view, TQT_SIGNAL(cutIncidenceSignal(Incidence *)),
-           mMainView, TQT_SLOT(cutIncidence(Incidence *)) );
-  connect( view, TQT_SIGNAL(pasteIncidenceSignal()),
-           mMainView, TQT_SLOT(pasteIncidence()));
-  connect( view, TQT_SIGNAL(toggleAlarmSignal(Incidence *)),
-           mMainView, TQT_SLOT(toggleAlarm(Incidence *)) );
-  connect( view,TQT_SIGNAL(dissociateOccurrenceSignal(Incidence *,const TQDate &)),
-           mMainView, TQT_SLOT(dissociateOccurrence(Incidence *,const TQDate &)) );
-  connect( view,TQT_SIGNAL(dissociateFutureOccurrenceSignal(Incidence *,const TQDate &)),
-           mMainView, TQT_SLOT(dissociateFutureOccurrence(Incidence *,const TQDate &)) );
+  connect( view, TQ_SIGNAL(showIncidenceSignal(Incidence *,const TQDate &)),
+           mMainView, TQ_SLOT(showIncidence(Incidence *,const TQDate &)) );
+  connect( view, TQ_SIGNAL(editIncidenceSignal(Incidence *,const TQDate &)),
+           mMainView, TQ_SLOT(editIncidence(Incidence *,const TQDate &)) );
+  connect( view, TQ_SIGNAL(deleteIncidenceSignal(Incidence *)),
+           mMainView, TQ_SLOT(deleteIncidence(Incidence *)) );
+  connect( view, TQ_SIGNAL(copyIncidenceSignal(Incidence *)),
+           mMainView, TQ_SLOT(copyIncidence(Incidence *)) );
+  connect( view, TQ_SIGNAL(cutIncidenceSignal(Incidence *)),
+           mMainView, TQ_SLOT(cutIncidence(Incidence *)) );
+  connect( view, TQ_SIGNAL(pasteIncidenceSignal()),
+           mMainView, TQ_SLOT(pasteIncidence()));
+  connect( view, TQ_SIGNAL(toggleAlarmSignal(Incidence *)),
+           mMainView, TQ_SLOT(toggleAlarm(Incidence *)) );
+  connect( view,TQ_SIGNAL(dissociateOccurrenceSignal(Incidence *,const TQDate &)),
+           mMainView, TQ_SLOT(dissociateOccurrence(Incidence *,const TQDate &)) );
+  connect( view,TQ_SIGNAL(dissociateFutureOccurrenceSignal(Incidence *,const TQDate &)),
+           mMainView, TQ_SLOT(dissociateFutureOccurrence(Incidence *,const TQDate &)) );
 
   // signals to create new incidences
-  connect( view, TQT_SIGNAL(newEventSignal(ResourceCalendar *,const TQString &)),
-           mMainView, TQT_SLOT(newEvent(ResourceCalendar *,const TQString &)) );
-  connect( view, TQT_SIGNAL(newEventSignal(ResourceCalendar *,const TQString &,const TQDate &)),
-           mMainView, TQT_SLOT(newEvent(ResourceCalendar *,const TQString &,const TQDate &)) );
-  connect( view, TQT_SIGNAL(newEventSignal(ResourceCalendar *,const TQString &,const TQDateTime &)),
-           mMainView, TQT_SLOT(newEvent(ResourceCalendar *,const TQString &,const TQDateTime &)) );
-  connect( view, TQT_SIGNAL(newEventSignal(ResourceCalendar *,const TQString &,const TQDateTime &,const TQDateTime &)),
-           mMainView, TQT_SLOT(newEvent(ResourceCalendar *,const TQString &,const TQDateTime &,const TQDateTime &)) );
+  connect( view, TQ_SIGNAL(newEventSignal(ResourceCalendar *,const TQString &)),
+           mMainView, TQ_SLOT(newEvent(ResourceCalendar *,const TQString &)) );
+  connect( view, TQ_SIGNAL(newEventSignal(ResourceCalendar *,const TQString &,const TQDate &)),
+           mMainView, TQ_SLOT(newEvent(ResourceCalendar *,const TQString &,const TQDate &)) );
+  connect( view, TQ_SIGNAL(newEventSignal(ResourceCalendar *,const TQString &,const TQDateTime &)),
+           mMainView, TQ_SLOT(newEvent(ResourceCalendar *,const TQString &,const TQDateTime &)) );
+  connect( view, TQ_SIGNAL(newEventSignal(ResourceCalendar *,const TQString &,const TQDateTime &,const TQDateTime &)),
+           mMainView, TQ_SLOT(newEvent(ResourceCalendar *,const TQString &,const TQDateTime &,const TQDateTime &)) );
 
-  connect( view, TQT_SIGNAL(newTodoSignal(ResourceCalendar *,const TQString &,const TQDate &)),
-           mMainView, TQT_SLOT(newTodo(ResourceCalendar *,const TQString &,const TQDate &)) );
-  connect( view, TQT_SIGNAL(newSubTodoSignal(Todo *)),
-           mMainView, TQT_SLOT(newSubTodo(Todo *)) );
+  connect( view, TQ_SIGNAL(newTodoSignal(ResourceCalendar *,const TQString &,const TQDate &)),
+           mMainView, TQ_SLOT(newTodo(ResourceCalendar *,const TQString &,const TQDate &)) );
+  connect( view, TQ_SIGNAL(newSubTodoSignal(Todo *)),
+           mMainView, TQ_SLOT(newSubTodo(Todo *)) );
 
-  connect( view, TQT_SIGNAL(newJournalSignal(ResourceCalendar *,const TQString &,const TQDate &)),
-           mMainView, TQT_SLOT(newJournal(ResourceCalendar *,const TQString &,const TQDate &)) );
+  connect( view, TQ_SIGNAL(newJournalSignal(ResourceCalendar *,const TQString &,const TQDate &)),
+           mMainView, TQ_SLOT(newJournal(ResourceCalendar *,const TQString &,const TQDate &)) );
 
   // reload settings
-  connect(mMainView, TQT_SIGNAL(configChanged()), view, TQT_SLOT(updateConfig()));
+  connect(mMainView, TQ_SIGNAL(configChanged()), view, TQ_SLOT(updateConfig()));
 
   // Notifications about added, changed and deleted incidences
-  connect( mMainView, TQT_SIGNAL( dayPassed( const TQDate & ) ),
-           view, TQT_SLOT( dayPassed( const TQDate & ) ) );
-  connect( view, TQT_SIGNAL( startMultiModify( const TQString & ) ),
-           mMainView, TQT_SLOT( startMultiModify( const TQString & ) ) );
-  connect( view, TQT_SIGNAL( endMultiModify() ),
-           mMainView, TQT_SLOT( endMultiModify() ) );
+  connect( mMainView, TQ_SIGNAL( dayPassed( const TQDate & ) ),
+           view, TQ_SLOT( dayPassed( const TQDate & ) ) );
+  connect( view, TQ_SIGNAL( startMultiModify( const TQString & ) ),
+           mMainView, TQ_SLOT( startMultiModify( const TQString & ) ) );
+  connect( view, TQ_SIGNAL( endMultiModify() ),
+           mMainView, TQ_SLOT( endMultiModify() ) );
 
-  connect( mMainView, TQT_SIGNAL( newIncidenceChanger( IncidenceChangerBase* ) ),
-           view, TQT_SLOT( setIncidenceChanger( IncidenceChangerBase * ) ) );
+  connect( mMainView, TQ_SIGNAL( newIncidenceChanger( IncidenceChangerBase* ) ),
+           view, TQ_SLOT( setIncidenceChanger( IncidenceChangerBase * ) ) );
   view->setIncidenceChanger( mMainView->incidenceChanger() );
 }
 
@@ -287,12 +287,12 @@ void KOViewManager::connectTodoView( KOTodoView* todoView )
   if (!todoView) return;
 
   // SIGNALS/SLOTS FOR TODO VIEW
-  connect( todoView, TQT_SIGNAL( purgeCompletedSignal() ),
-           mMainView, TQT_SLOT( purgeCompleted() ) );
-  connect( todoView, TQT_SIGNAL( unSubTodoSignal() ),
-           mMainView, TQT_SLOT( todo_unsub() ) );
-  connect( todoView, TQT_SIGNAL( unAllSubTodoSignal() ),
-           mMainView, TQT_SLOT( makeSubTodosIndependent() ) );
+  connect( todoView, TQ_SIGNAL( purgeCompletedSignal() ),
+           mMainView, TQ_SLOT( purgeCompleted() ) );
+  connect( todoView, TQ_SIGNAL( unSubTodoSignal() ),
+           mMainView, TQ_SLOT( todo_unsub() ) );
+  connect( todoView, TQ_SIGNAL( unAllSubTodoSignal() ),
+           mMainView, TQ_SLOT( makeSubTodosIndependent() ) );
 }
 
 void KOViewManager::zoomInHorizontally()
@@ -357,8 +357,8 @@ void KOViewManager::showAgendaView()
   TQWidget *parent = mMainView->viewStack();
   if ( !mAgendaViewTabs && showBoth ) {
     mAgendaViewTabs = new TQTabWidget( mMainView->viewStack() );
-    connect( mAgendaViewTabs, TQT_SIGNAL( currentChanged( TQWidget* ) ),
-             this, TQT_SLOT( currentAgendaViewTabChanged( TQWidget* ) ) );
+    connect( mAgendaViewTabs, TQ_SIGNAL( currentChanged( TQWidget* ) ),
+             this, TQ_SLOT( currentAgendaViewTabChanged( TQWidget* ) ) );
     parent = mAgendaViewTabs;
 
     TDEConfig *config = KOGlobals::self()->config();
@@ -374,13 +374,13 @@ void KOViewManager::showAgendaView()
 
     addView(mAgendaView);
 
-    connect(mAgendaView, TQT_SIGNAL( toggleExpand() ),
-            mMainView, TQT_SLOT( toggleExpand() ) );
-    connect(mMainView, TQT_SIGNAL( calendarViewExpanded( bool ) ),
-            mAgendaView, TQT_SLOT( setExpandedButton( bool ) ) );
+    connect(mAgendaView, TQ_SIGNAL( toggleExpand() ),
+            mMainView, TQ_SLOT( toggleExpand() ) );
+    connect(mMainView, TQ_SIGNAL( calendarViewExpanded( bool ) ),
+            mAgendaView, TQ_SLOT( setExpandedButton( bool ) ) );
 
-    connect( mAgendaView,TQT_SIGNAL( zoomViewHorizontally(const TQDate &, int )),
-             mMainView->dateNavigator(),TQT_SLOT( selectDates( const TQDate &, int ) ) );
+    connect( mAgendaView,TQ_SIGNAL( zoomViewHorizontally(const TQDate &, int )),
+             mMainView->dateNavigator(),TQ_SLOT( selectDates( const TQDate &, int ) ) );
     mAgendaView->readSettings();
   }
 
@@ -391,13 +391,13 @@ void KOViewManager::showAgendaView()
 
     addView(mAgendaSideBySideView);
 
-/*    connect(mAgendaSideBySideView, TQT_SIGNAL( toggleExpand() ),
-            mMainView, TQT_SLOT( toggleExpand() ) );
-    connect(mMainView, TQT_SIGNAL( calendarViewExpanded( bool ) ),
-            mAgendaSideBySideView, TQT_SLOT( setExpandedButton( bool ) ) );
+/*    connect(mAgendaSideBySideView, TQ_SIGNAL( toggleExpand() ),
+            mMainView, TQ_SLOT( toggleExpand() ) );
+    connect(mMainView, TQ_SIGNAL( calendarViewExpanded( bool ) ),
+            mAgendaSideBySideView, TQ_SLOT( setExpandedButton( bool ) ) );
 
-    connect( mAgendaSideBySideView,TQT_SIGNAL( zoomViewHorizontally(const TQDate &, int )),
-             mMainView->dateNavigator(),TQT_SLOT( selectDates( const TQDate &, int ) ) );*/
+    connect( mAgendaSideBySideView,TQ_SIGNAL( zoomViewHorizontally(const TQDate &, int )),
+             mMainView->dateNavigator(),TQ_SLOT( selectDates( const TQDate &, int ) ) );*/
   }
 
   if ( showBoth && mAgendaViewTabs ) {
