@@ -27,7 +27,7 @@
 */
 class ConfigDialog:public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
