@@ -49,8 +49,8 @@ KornAccountCfgImpl::KornAccountCfgImpl( TQWidget * parent, const char * name )
 	_groupBoxes( 0 ),
 	_accountinput( new TQPtrList< AccountInput >() )
 {
-	connect( parent, TQT_SIGNAL( okClicked() ), this, TQT_SLOT( slotOK() ) );
-	connect( parent, TQT_SIGNAL( cancelClicked() ), this, TQT_SLOT( slotCancel() ) );
+	connect( parent, TQ_SIGNAL( okClicked() ), this, TQ_SLOT( slotOK() ) );
+	connect( parent, TQ_SIGNAL( cancelClicked() ), this, TQ_SLOT( slotCancel() ) );
 	
 	this->cbProtocol->insertStringList( Protocols::getProtocols() );
 
@@ -195,7 +195,7 @@ void KornAccountCfgImpl::slotProtocolChanged( const TQString& proto )
 	delete groupBoxes;
 
 	AccountInput *input;
-	protocol->configFields( _groupBoxes, TQT_TQOBJECT(this), _accountinput );
+	protocol->configFields( _groupBoxes, this, _accountinput );
 	
 	for( unsigned int groupCounter = 0; groupCounter < _groupBoxes->count(); ++groupCounter )
 	{
