@@ -17,7 +17,7 @@
 #ifndef __KMIME_BOOLFLAGS_H__
 #define __KMIME_BOOLFLAGS_H__
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 /** This class stores boolean values in single bytes.
     It provides a similar functionality as TQBitArray
@@ -25,7 +25,7 @@
     We use it to store the flags of an article
     @internal
 */
-class KDE_EXPORT BoolFlags {
+class TDE_EXPORT BoolFlags {
 
 public:
   BoolFlags()       { clear(); }
