@@ -1104,7 +1104,7 @@ bool parseParameter( const char* & scursor, const char * const send,
 	"Chopping away \"*\"." << endl;
       maybeAttribute.truncate( maybeAttribute.length() - 1 );
     }
-    result = tqMakePair( maybeAttribute.lower(), TQStringOrTQPair() );
+    result = qMakePair( maybeAttribute.lower(), TQStringOrTQPair() );
     return true;
   }
 
@@ -1128,19 +1128,19 @@ bool parseParameter( const char* & scursor, const char * const send,
 
     if ( !parseGenericQuotedString( scursor, send, maybeValue.qstring, isCRLF ) ) {
       scursor = oldscursor;
-      result = tqMakePair( maybeAttribute.lower(), TQStringOrTQPair() );
+      result = qMakePair( maybeAttribute.lower(), TQStringOrTQPair() );
       return false; // this case needs further processing by upper layers!!
     }
   } else {
     // value is a token:
     if ( !parseToken( scursor, send, maybeValue.qpair, false /* no 8bit */ ) ) {
       scursor = oldscursor;
-      result = tqMakePair( maybeAttribute.lower(), TQStringOrTQPair() );
+      result = qMakePair( maybeAttribute.lower(), TQStringOrTQPair() );
       return false; // this case needs further processing by upper layers!!
     }
   }
 
-  result = tqMakePair( maybeAttribute.lower(), maybeValue );
+  result = qMakePair( maybeAttribute.lower(), maybeValue );
   return true;
 }
 
