@@ -92,10 +92,10 @@ void ExchangeDownload::download( KCal::Calendar *calendar, const TQDate &start,
     mProgress = new ExchangeProgress();
     mProgress->show();
 
-    connect( this, TQT_SIGNAL( startDownload() ), mProgress,
-             TQT_SLOT( slotTransferStarted() ) );
-    connect( this, TQT_SIGNAL(finishDownload() ), mProgress,
-             TQT_SLOT( slotTransferFinished() ) );
+    connect( this, TQ_SIGNAL( startDownload() ), mProgress,
+             TQ_SLOT( slotTransferStarted() ) );
+    connect( this, TQ_SIGNAL(finishDownload() ), mProgress,
+             TQ_SLOT( slotTransferFinished() ) );
 #endif
   }
 
@@ -112,8 +112,8 @@ void ExchangeDownload::download( KCal::Calendar *calendar, const TQDate &start,
                                      sql, false );
   TDEIO::Scheduler::scheduleJob( job );
   job->setWindow( mWindow );
-  connect( job, TQT_SIGNAL( result( TDEIO::Job * ) ),
-           TQT_SLOT( slotSearchResult( TDEIO::Job *) ) );
+  connect( job, TQ_SIGNAL( result( TDEIO::Job * ) ),
+           TQ_SLOT( slotSearchResult( TDEIO::Job *) ) );
 }
 
 void ExchangeDownload::download( const TQDate& start, const TQDate& end, bool showProgress )
@@ -126,8 +126,8 @@ void ExchangeDownload::download( const TQDate& start, const TQDate& end, bool sh
     mProgress = new ExchangeProgress();
     mProgress->show();
 
-    connect( this, TQT_SIGNAL(startDownload()), mProgress, TQT_SLOT(slotTransferStarted()) );
-    connect( this, TQT_SIGNAL(finishDownload()), mProgress, TQT_SLOT(slotTransferFinished()) );
+    connect( this, TQ_SIGNAL(startDownload()), mProgress, TQ_SLOT(slotTransferStarted()) );
+    connect( this, TQ_SIGNAL(finishDownload()), mProgress, TQ_SLOT(slotTransferFinished()) );
   }
 
   TQString sql = dateSelectQuery( start, end.addDays( 1 ) );
@@ -137,8 +137,8 @@ void ExchangeDownload::download( const TQDate& start, const TQDate& end, bool sh
   TDEIO::DavJob *job = TDEIO::davSearch( mAccount->calendarURL(), "DAV:", "sql", sql, false );
   TDEIO::Scheduler::scheduleJob(job);
   job->setWindow( mWindow );
-  connect( job, TQT_SIGNAL( result( TDEIO::Job * ) ),
-           TQT_SLOT( slotSearchResult( TDEIO::Job * ) ) );
+  connect( job, TQ_SIGNAL( result( TDEIO::Job * ) ),
+           TQ_SLOT( slotSearchResult( TDEIO::Job * ) ) );
 }
 
 // Original query TODO: make query configurable
@@ -301,8 +301,8 @@ void ExchangeDownload::handleRecurrence( TQString uid )
                                      query, false );
   TDEIO::Scheduler::scheduleJob( job );
   job->setWindow( mWindow );
-  connect( job, TQT_SIGNAL( result( TDEIO::Job * ) ),
-           TQT_SLOT( slotMasterResult( TDEIO::Job * ) ) );
+  connect( job, TQ_SIGNAL( result( TDEIO::Job * ) ),
+           TQ_SLOT( slotMasterResult( TDEIO::Job * ) ) );
 }
 
 void ExchangeDownload::readAppointment( const KURL& url )
@@ -349,8 +349,8 @@ void ExchangeDownload::readAppointment( const KURL& url )
   TDEIO::Scheduler::scheduleJob( job );
   job->setWindow( mWindow );
   job->addMetaData( "errorPage", "false" );
-  connect( job, TQT_SIGNAL( result( TDEIO::Job * ) ),
-           TQT_SLOT( slotPropFindResult( TDEIO::Job * ) ) );
+  connect( job, TQ_SIGNAL( result( TDEIO::Job * ) ),
+           TQ_SLOT( slotPropFindResult( TDEIO::Job * ) ) );
 }
 
 void ExchangeDownload::slotPropFindResult( TDEIO::Job *job )
@@ -401,7 +401,7 @@ void ExchangeDownload::slotPropFindResult( TDEIO::Job *job )
 
   TQString lastModified = prop.namedItem( "lastmodified" ).toElement().text();
   if ( !lastModified.isEmpty() ) {
-    TQDateTime dt = utcAsZone( TQDateTime::fromString( lastModified, Qt::ISODate ), localTimeZoneId );
+    TQDateTime dt = utcAsZone( TQDateTime::fromString( lastModified, TQt::ISODate ), localTimeZoneId );
     event->setLastModified( dt );
     kdDebug() << "Got lastModified:" << lastModified << ", " << dt.toString() << endl;
   }
@@ -436,7 +436,7 @@ void ExchangeDownload::slotPropFindResult( TDEIO::Job *job )
 
   TQString created = prop.namedItem( "created" ).toElement().text();
   if ( !created.isEmpty() ) {
-    TQDateTime dt = utcAsZone( TQDateTime::fromString( created, Qt::ISODate ),
+    TQDateTime dt = utcAsZone( TQDateTime::fromString( created, TQt::ISODate ),
                     localTimeZoneId );
     event->setCreated( dt );
     kdDebug() << "got created: " << dt.toString() << endl;
@@ -444,7 +444,7 @@ void ExchangeDownload::slotPropFindResult( TDEIO::Job *job )
 
   TQString dtstart = prop.namedItem( "dtstart" ).toElement().text();
   if ( !dtstart.isEmpty() ) {
-    TQDateTime dt = utcAsZone( TQDateTime::fromString( dtstart, Qt::ISODate ),
+    TQDateTime dt = utcAsZone( TQDateTime::fromString( dtstart, TQt::ISODate ),
                               localTimeZoneId );
     event->setDtStart( dt );
     kdDebug() << "got dtstart: " << dtstart << " becomes in timezone " << dt.toString() << endl;
@@ -457,7 +457,7 @@ void ExchangeDownload::slotPropFindResult( TDEIO::Job *job )
 
   TQString dtend = prop.namedItem( "dtend" ).toElement().text();
   if ( !dtend.isEmpty() ) {
-    TQDateTime dt = utcAsZone( TQDateTime::fromString( dtend, Qt::ISODate ),
+    TQDateTime dt = utcAsZone( TQDateTime::fromString( dtend, TQt::ISODate ),
                               localTimeZoneId );
     // Outlook thinks differently about floating event timing than libkcal
     if ( floats ) dt = dt.addDays( -1 );
@@ -510,7 +510,7 @@ void ExchangeDownload::slotPropFindResult( TDEIO::Job *job )
   list = exdate.elementsByTagNameNS( "xml:", "v" );
   for( uint i=0; i < list.count(); i++ ) {
     TQDomElement item = list.item(i).toElement();
-    TQDate date = utcAsZone( TQDateTime::fromString( item.text(), Qt::ISODate ), localTimeZoneId ).date();
+    TQDate date = utcAsZone( TQDateTime::fromString( item.text(), TQt::ISODate ), localTimeZoneId ).date();
     exdates.append( date );
     // kdDebug() << "Got exdate: " << date.toString() << endl;
   }
