@@ -31,7 +31,6 @@ namespace GpgME {
 
   class Key;
   class Data;
-  class TrustItem;
   class ProgressProvider;
   class PassphraseProvider;
   class EventLoopInteractor;
@@ -179,14 +178,6 @@ namespace GpgME {
     GpgME::Error deleteKey( const Key & key, bool allowSecretKeyDeletion=false );
     GpgME::Error startKeyDeletion( const Key & key, bool allowSecretKeyDeletion=false );
 
-    //
-    // Trust Item Management
-    //
-
-    GpgME::Error startTrustItemListing( const char * pattern, int maxLevel );
-    TrustItem nextTrustItem( GpgME::Error & e );
-    GpgME::Error endTrustItemListing();
-
     //
     //
     // Crypto Operations
