@@ -151,8 +151,8 @@ void AddresseeLineEdit::init()
     completionSourceWeightsDeleter.setObject( s_completionSourceWeights, new TQMap<TQString,int> );
     ldapClientToCompletionSourceMapDeleter.setObject( s_ldapClientToCompletionSourceMap, new TQMap<int,int> );
   }
-//  connect( s_completion, TQT_SIGNAL( match( const TQString& ) ),
-//           this, TQT_SLOT( slotMatched( const TQString& ) ) );
+//  connect( s_completion, TQ_SIGNAL( match( const TQString& ) ),
+//           this, TQ_SLOT( slotMatched( const TQString& ) ) );
 
   if ( m_useCompletion ) {
     if ( !s_LDAPTimer ) {
@@ -165,25 +165,25 @@ void AddresseeLineEdit::init()
 
     if ( !m_completionInitialized ) {
       setCompletionObject( s_completion, false );
-      connect( this, TQT_SIGNAL( completion( const TQString& ) ),
-          this, TQT_SLOT( slotCompletion() ) );
-      connect( this, TQT_SIGNAL( returnPressed( const TQString& ) ),
-          this, TQT_SLOT( slotReturnPressed( const TQString& ) ) );
+      connect( this, TQ_SIGNAL( completion( const TQString& ) ),
+          this, TQ_SLOT( slotCompletion() ) );
+      connect( this, TQ_SIGNAL( returnPressed( const TQString& ) ),
+          this, TQ_SLOT( slotReturnPressed( const TQString& ) ) );
 
       TDECompletionBox *box = completionBox();
-      connect( box, TQT_SIGNAL( highlighted( const TQString& ) ),
-          this, TQT_SLOT( slotPopupCompletion( const TQString& ) ) );
-      connect( box, TQT_SIGNAL( userCancelled( const TQString& ) ),
-          TQT_SLOT( slotUserCancelled( const TQString& ) ) );
+      connect( box, TQ_SIGNAL( highlighted( const TQString& ) ),
+          this, TQ_SLOT( slotPopupCompletion( const TQString& ) ) );
+      connect( box, TQ_SIGNAL( userCancelled( const TQString& ) ),
+          TQ_SLOT( slotUserCancelled( const TQString& ) ) );
 
       // The emitter is always called KPIM::IMAPCompletionOrder by contract
       if ( !connectDCOPSignal( 0, "KPIM::IMAPCompletionOrder", "orderChanged()",
             "slotIMAPCompletionOrderChanged()", false ) )
         kdError() << "AddresseeLineEdit: connection to orderChanged() failed" << endl;
 
-      connect( s_LDAPTimer, TQT_SIGNAL( timeout() ), TQT_SLOT( slotStartLDAPLookup() ) );
-      connect( s_LDAPSearch, TQT_SIGNAL( searchData( const KPIM::LdapResultList& ) ),
-          TQT_SLOT( slotLDAPSearchData( const KPIM::LdapResultList& ) ) );
+      connect( s_LDAPTimer, TQ_SIGNAL( timeout() ), TQ_SLOT( slotStartLDAPLookup() ) );
+      connect( s_LDAPSearch, TQ_SIGNAL( searchData( const KPIM::LdapResultList& ) ),
+          TQ_SLOT( slotLDAPSearchData( const KPIM::LdapResultList& ) ) );
 
       m_completionInitialized = true;
     }
@@ -346,7 +346,7 @@ void AddresseeLineEdit::mouseReleaseEvent( TQMouseEvent *e )
   if ( m_useCompletion
        && TQApplication::clipboard()->supportsSelection()
        && !isReadOnly()
-       && e->button() == Qt::MidButton ) {
+       && e->button() == TQt::MidButton ) {
     m_smartPaste = true;
   }
 
@@ -607,7 +607,7 @@ void AddresseeLineEdit::loadContacts()
   TQApplication::restoreOverrideCursor();
 
   if ( !m_addressBookConnected ) {
-    connect( addressBook, TQT_SIGNAL( addressBookChanged( AddressBook* ) ), TQT_SLOT( loadContacts() ) );
+    connect( addressBook, TQ_SIGNAL( addressBookChanged( AddressBook* ) ), TQ_SLOT( loadContacts() ) );
     m_addressBookConnected = true;
   }
 }
@@ -763,7 +763,7 @@ void AddresseeLineEdit::addCompletionItem( const TQString& string, int weight, i
     weight = TQMAX( ( *it ).first, weight );
     ( *it ).first = weight;
   } else {
-    s_completionItemMap->insert( string, tqMakePair( weight, completionItemSource ) );
+    s_completionItemMap->insert( string, qMakePair( weight, completionItemSource ) );
   }
   if ( keyWords == 0 )
     s_completion->addItem( string, weight );
@@ -925,7 +925,7 @@ TQPopupMenu* AddresseeLineEdit::createPopupMenu()
     menu->setItemVisible( ShortAutoCompletion, false );
     menu->setItemVisible( PopupAutoCompletion, false );
     menu->insertItem( i18n( "Configure Completion Order..." ),
-                      this, TQT_SLOT( slotEditCompletionOrder() ) );
+                      this, TQ_SLOT( slotEditCompletionOrder() ) );
   }
   return menu;
 }
@@ -1037,12 +1037,12 @@ int KPIM::AddresseeLineEdit::addCompletionSource( const TQString &source, int we
 
 bool KPIM::AddresseeLineEdit::eventFilter(TQObject *obj, TQEvent *e)
 {
-  if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(completionBox()) ) {
+  if ( obj == completionBox() ) {
     if ( e->type() == TQEvent::MouseButtonPress ||
          e->type() == TQEvent::MouseMove ||
          e->type() == TQEvent::MouseButtonRelease ||
          e->type() == TQEvent::MouseButtonDblClick ) {
-      TQMouseEvent* me = TQT_TQMOUSEEVENT( e );
+      TQMouseEvent* me = static_cast<TQMouseEvent*>( e );
       // find list box item at the event position
       TQListBoxItem *item = completionBox()->itemAt( me->pos() );
       if ( !item ) {
@@ -1054,8 +1054,8 @@ bool KPIM::AddresseeLineEdit::eventFilter(TQObject *obj, TQEvent *e)
       // avoid selection of headers on button press, or move or release while
       // a button is pressed
       if ( e->type() == TQEvent::MouseButtonPress
-          || me->state() & Qt::LeftButton || me->state() & Qt::MidButton
-          || me->state() & Qt::RightButton ) {
+          || me->state() & TQt::LeftButton || me->state() & TQt::MidButton
+          || me->state() & TQt::RightButton ) {
         if ( itemIsHeader(item) ) {
           return true; // eat the event, we don't want anything to happen
         } else {
@@ -1070,18 +1070,18 @@ bool KPIM::AddresseeLineEdit::eventFilter(TQObject *obj, TQEvent *e)
       }
     }
   }
-  if ( ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(this) ) &&
+  if ( ( obj == this ) &&
      ( e->type() == TQEvent::AccelOverride ) ) {
-    TQKeyEvent *ke = TQT_TQKEYEVENT( e );
+    TQKeyEvent *ke = static_cast<TQKeyEvent*>( e );
     if ( ke->key() == Key_Up || ke->key() == Key_Down || ke->key() == Key_Tab ) {
       ke->accept();
       return true;
     }
   }
-  if ( ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(this) ) &&
+  if ( ( obj == this ) &&
        ( e->type() == TQEvent::KeyPress || e->type() == TQEvent::KeyRelease ) &&
        completionBox()->isVisible() ) {
-    TQKeyEvent *ke = TQT_TQKEYEVENT( e );
+    TQKeyEvent *ke = static_cast<TQKeyEvent*>( e );
     int currentIndex = completionBox()->currentItem();
     if ( currentIndex < 0 ) {
       return true;
