@@ -27,7 +27,7 @@
 #include <tdeabc/addressee.h>
 #include <ktextbrowser.h>
 #include <tdeimproxy.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 namespace TDEIO {
 class Job;
@@ -40,9 +40,9 @@ class TQPopupMenu;
 namespace KPIM {
 
 
-class KDE_EXPORT AddresseeView : public KTextBrowser
+class TDE_EXPORT AddresseeView : public KTextBrowser
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     /**
