@@ -235,10 +235,10 @@ CompletionOrderEditor::CompletionOrderEditor( KPIM::LdapSearch* ldapSearch,
   TQWidget* spacer = new TQWidget( upDownBox );
   upDownBox->setStretchFactor( spacer, 100 );
 
-  connect( mListView, TQT_SIGNAL( selectionChanged( TQListViewItem* ) ),
-           TQT_SLOT( slotSelectionChanged( TQListViewItem* ) ) );
-  connect( mUpButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotMoveUp() ) );
-  connect( mDownButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotMoveDown() ) );
+  connect( mListView, TQ_SIGNAL( selectionChanged( TQListViewItem* ) ),
+           TQ_SLOT( slotSelectionChanged( TQListViewItem* ) ) );
+  connect( mUpButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotMoveUp() ) );
+  connect( mDownButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotMoveDown() ) );
 }
 
 CompletionOrderEditor::~CompletionOrderEditor()
