@@ -19,7 +19,7 @@
 
 #include <tqobject.h>
 
-#include <tdepimmacros.h>
+#include <tdemacros.h>
 
 class KMKernel;
 
@@ -29,8 +29,8 @@ namespace KPIM {
  * @short Class for managing a set of config options.
  * @author Marc Mutz <mutz@kde.org>
  **/
-class KDE_EXPORT ConfigManager : public TQObject {
-  Q_OBJECT
+class TDE_EXPORT ConfigManager : public TQObject {
+  TQ_OBJECT
   
 public:
   /** Commit changes to disk and emit changed() if necessary. */
