@@ -23,7 +23,7 @@
 #define KPIM_KCMDESIGNERFIELDS_H
 
 #include <tdecmodule.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 class TDEListView;
 
@@ -33,9 +33,9 @@ class TQPushButton;
 
 namespace KPIM {
 
-class KDE_EXPORT KCMDesignerFields : public TDECModule
+class TDE_EXPORT KCMDesignerFields : public TDECModule
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
