@@ -26,7 +26,7 @@
 #include <tqdragobject.h>
 #include <tqcolor.h>
 #include <tdelistview.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 class KFolderTree;
 
@@ -139,7 +139,7 @@ struct KPaintInfo {
 
 //==========================================================================
 
-class KDE_EXPORT KFolderTreeItem : public TDEListViewItem
+class TDE_EXPORT KFolderTreeItem : public TDEListViewItem
 {
   public:
     /** Protocol information */
@@ -238,9 +238,9 @@ class KDE_EXPORT KFolderTreeItem : public TDEListViewItem
 
 //==========================================================================
 
-class KDE_EXPORT KFolderTree : public TDEListView
+class TDE_EXPORT KFolderTree : public TDEListView
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
