@@ -30,7 +30,7 @@ namespace Komposer
 
   class CoreWidget : public TQWidget
   {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     CoreWidget( TQWidget *parent, const char *name=0 );
