@@ -27,7 +27,7 @@
 
 #include <tdeabc/addressee.h>
 #include <tdeabc/vcardparser.h> // for KABC_VCARD_ENCODING_FIX define
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 class KVCardDragPrivate;
 
@@ -37,7 +37,7 @@ class KVCardDragPrivate;
  *
  * See the TQt drag'n'drop documentation.
  */
-class KDE_EXPORT KVCardDrag : public TQStoredDrag
+class TDE_EXPORT KVCardDrag : public TQStoredDrag
 {
   TQ_OBJECT
   
