@@ -29,7 +29,7 @@ class TQTextEdit;
 
 class SendSMSDialog : public KDialogBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
