@@ -15,6 +15,6 @@ int main( int argc, char ** argv )
 
   MainWindow *w = new MainWindow;
   w->show();
-  app.connect( &app, TQT_SIGNAL( lastWindowClosed() ), &app, TQT_SLOT( quit() ) );
+  app.connect( &app, TQ_SIGNAL( lastWindowClosed() ), &app, TQ_SLOT( quit() ) );
   return app.exec();
 }
