@@ -540,7 +540,7 @@ imapParser::parseResult (TQByteArray & result, parseString & rest,
   if (rest[0] == '[')
   {
     rest.pos++;
-    TQCString option = parseOneWordC(rest, TRUE);
+    TQCString option = parseOneWordC(rest, true);
 
     switch (option[0])
     {
@@ -1346,7 +1346,7 @@ void imapParser::parseBody (parseString & inWords)
     TQCString label;
     inWords.pos++;
 
-    specifier = parseOneWordC (inWords, TRUE);
+    specifier = parseOneWordC (inWords, true);
 
     if (inWords[0] == '(')
     {
@@ -1834,7 +1834,7 @@ bool imapParser::parseRead (TQByteArray & buffer, ulong len, ulong relay)
   Q_UNUSED(relay);
   tqWarning
     ("imapParser::parseRead - virtual function not reimplemented - no data read");
-  return FALSE;
+  return false;
 }
 
 bool imapParser::parseReadLine (TQByteArray & buffer, ulong relay)
@@ -1843,7 +1843,7 @@ bool imapParser::parseReadLine (TQByteArray & buffer, ulong relay)
   Q_UNUSED(relay);
   tqWarning
     ("imapParser::parseReadLine - virtual function not reimplemented - no data read");
-  return FALSE;
+  return false;
 }
 
 void
@@ -1975,11 +1975,11 @@ TQCString imapParser::parseOneWordC (parseString & inWords, bool stopAtBracket,
   if (len > 0 && inWords[0] == '"')
   {
     unsigned int i = 1;
-    bool quote = FALSE;
+    bool quote = false;
     while (i < len && (inWords[i] != '"' || quote))
     {
       if (inWords[i] == '\\') quote = !quote;
-      else quote = FALSE;
+      else quote = false;
       i++;
     }
     if (i < len)
@@ -2049,7 +2049,7 @@ TQCString imapParser::parseOneWordC (parseString & inWords, bool stopAtBracket,
 bool imapParser::parseOneNumber (parseString & inWords, ulong & num)
 {
   bool valid;
-  num = parseOneWordC(inWords, TRUE).toULong(&valid);
+  num = parseOneWordC(inWords, true).toULong(&valid);
   return valid;
 }
 
