@@ -139,25 +139,12 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 # endif
 #endif
 
-#ifdef __BORLANDC__
-# ifdef __WIN32__
-#  ifndef WIN32
-#   define WIN32
-#  endif
-# endif
-#endif
-
 #ifdef __CYGWIN__
 # ifndef CYGWIN
 #  define CYGWIN
 # endif
 #endif
 
-#ifdef __SYMBIAN32__
-# define SYMBIAN
-# undef WIN32
-#endif
-
 #if defined(__palmos__) || defined(PALM_GCC) || defined(__PALMOS_TRAPS__)
 # ifndef PALM
 #  define PALM
@@ -291,24 +278,6 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 #  define HAVE_WCTOMB
 #  define HAVE_MBTOWC
 #  define HAVE_ISNAN
-# elif defined(__osf__)
-#  define HAVE_STRRCHR
-#  define HAVE_STRTOD
-#  define HAVE_SSCANF
-#  define HAVE_STRTOL
-#  define HAVE_STRTOUL
-#  define HAVE_STRTOLL
-#  define HAVE_STRTOULL
-#  define HAVE_GETTIMEOFDAY
-#  define HAVE_SYS_TIMEB_H
-#  define HAVE_RAND_R
-#  define HAVE_GMTIME_R
-#  define HAVE_LOCALTIME_R
-#  define __USE_STD_IOSTREAM
-#  define HAVE_WCTOMB
-#  define HAVE_MBTOWC
-#  define SOAP_LONG_FORMAT "%ld"
-#  define SOAP_ULONG_FORMAT "%lu"
 # elif defined(MAC_CARBON)
 #  define WITH_NOIO
 #  define HAVE_STRRCHR
@@ -333,12 +302,6 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 #  define O_NONBLOCK FNONBIO
 #  include <sys_socket.h>
 #  include "palmFunctions.h"
-# elif defined(SYMBIAN)
-#  define WITH_LEAN
-#  define WITH_NONAMESPACES
-#  define HAVE_STRTOD	/* use STRTOD since sscanf doesn't seem to work */
-#  include <e32def.h>
-#  include <sys/ioctl.h>
 # elif defined(VXWORKS)
 #  define HAVE_STRRCHR
 #  define HAVE_STRTOD
@@ -445,9 +408,7 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 #    include <sockLib.h>
 #   endif
 #   ifndef VXWORKS
-#    ifndef SYMBIAN
-#     include <strings.h>
-#    endif
+#    include <strings.h>
 #   endif
 #   ifdef SUN_OS
 #    include <sys/stream.h>		/* SUN */
@@ -549,7 +510,7 @@ extern "C" {
 # define SOAP_SOCKLEN_T SOCKLEN_T
 #elif defined(__socklen_t_defined) || defined(_SOCKLEN_T) || defined(CYGWIN) || defined(FREEBSD) || defined(__FreeBSD__) || defined(__TQNX__) || defined(TQNX) || defined(_AIX) || defined(__NetBSD__) || defined(__DragonFly__)
 # define SOAP_SOCKLEN_T socklen_t
-#elif defined(IRIX) || defined(WIN32) || defined(__APPLE__) || defined(HP_UX) || defined(SUN_OS) || defined(OPENSERVER) || defined(__osf__) || defined(VXWORKS)
+#elif defined(IRIX) || defined(WIN32) || defined(__APPLE__) || defined(HP_UX) || defined(SUN_OS) || defined(OPENSERVER) || defined(VXWORKS)
 # define SOAP_SOCKLEN_T int
 #else
 # define SOAP_SOCKLEN_T size_t
@@ -565,10 +526,7 @@ extern "C" {
 #define SOAP_INVALID_SOCKET (-1)
 #define soap_valid_socket(n) ((n) != SOAP_INVALID_SOCKET)
 
-#if defined(SYMBIAN)
-# define LONG64 long
-# define ULONG64 unsigned LONG64
-#elif !defined(WIN32) || defined(__GLIBC__) || defined(__GNU__)
+#if !defined(WIN32) || defined(__GLIBC__) || defined(__GNU__)
 # ifndef LONG64
 #  define LONG64 long long
 #  define ULONG64 unsigned LONG64
@@ -576,15 +534,10 @@ extern "C" {
 #elif defined(UNDER_CE)
 # define LONG64 __int64
 # define ULONG64 unsigned LONG64
-#elif defined(__BORLANDC__)
-# define LONG64 __int64
-# define ULONG64 unsigned LONG64
 #endif
 
 #if defined(WIN32)
 # define soap_int32 __int32
-#elif defined(SYMBIAN)
-# define soap_int32 long
 #elif defined(PALM)
 # define soap_int32 Int32
 #else
@@ -601,13 +554,8 @@ extern "C" {
 # define SOAP_ERANGE ERANGE
 # define SOAP_EINTR EINTR
 # define SOAP_EAGAIN EAGAIN
-# ifdef SYMBIAN
-#  define SOAP_EWOULDBLOCK 9898
-#  define SOAP_EINPROGRESS 9899
-# else
-#  define SOAP_EWOULDBLOCK EWOULDBLOCK
-#  define SOAP_EINPROGRESS EINPROGRESS
-# endif
+# define SOAP_EWOULDBLOCK EWOULDBLOCK
+# define SOAP_EINPROGRESS EINPROGRESS
 #endif
 
 #ifdef WIN32
