@@ -29,7 +29,7 @@ namespace KCal {
 /**
   This class provides a resource for accessing an Exchange server
 */
-class KDE_EXPORT ResourceExchange : public ResourceGroupwareBase
+class TDE_EXPORT ResourceExchange : public ResourceGroupwareBase
 {
     TQ_OBJECT
   
