@@ -25,7 +25,7 @@
 
 namespace TDEABC {
 
-class KDE_EXPORT ResourceExchange : public ResourceGroupwareBase
+class TDE_EXPORT ResourceExchange : public ResourceGroupwareBase
 {
   TQ_OBJECT
   
