@@ -36,7 +36,7 @@
 
 #include <tqtimer.h>
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 #include <libkcal/calendarlocal.h>
 #include <libkcal/icalformat.h>
 #include <libkcal/resourcecalendar.h>
@@ -46,11 +46,11 @@ namespace KCal {
 
 struct TemporarySilencer;
 
-class KDE_EXPORT ResourceScalix : public KCal::ResourceCalendar,
+class TDE_EXPORT ResourceScalix : public KCal::ResourceCalendar,
                       public KCal::IncidenceBase::Observer,
                       public Scalix::ResourceScalixBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
     friend struct TemporarySilencer;
 
