@@ -226,16 +226,16 @@ void KCalResourceSlox::requestEvents()
   kdDebug() << "REQUEST CALENDAR: \n" << doc.toString( 2 ) << endl;
 
   mLoadEventsJob = TDEIO::davPropFind( url, doc, "0", false );
-  connect( mLoadEventsJob, TQT_SIGNAL( result( TDEIO::Job * ) ),
-           TQT_SLOT( slotLoadEventsResult( TDEIO::Job * ) ) );
-  connect( mLoadEventsJob, TQT_SIGNAL( percent( TDEIO::Job *, unsigned long ) ),
-           TQT_SLOT( slotEventsProgress( TDEIO::Job *, unsigned long ) ) );
+  connect( mLoadEventsJob, TQ_SIGNAL( result( TDEIO::Job * ) ),
+           TQ_SLOT( slotLoadEventsResult( TDEIO::Job * ) ) );
+  connect( mLoadEventsJob, TQ_SIGNAL( percent( TDEIO::Job *, unsigned long ) ),
+           TQ_SLOT( slotEventsProgress( TDEIO::Job *, unsigned long ) ) );
 
   mLoadEventsProgress = KPIM::ProgressManager::instance()->createProgressItem(
       KPIM::ProgressManager::getUniqueID(), i18n("Downloading events") );
   connect( mLoadEventsProgress,
-           TQT_SIGNAL( progressItemCanceled( KPIM::ProgressItem * ) ),
-           TQT_SLOT( cancelLoadEvents() ) );
+           TQ_SIGNAL( progressItemCanceled( KPIM::ProgressItem * ) ),
+           TQ_SLOT( cancelLoadEvents() ) );
 
   mPrefs->setLastEventSync( TQDateTime::currentDateTime() );
 }
@@ -271,16 +271,16 @@ void KCalResourceSlox::requestTodos()
   kdDebug() << "REQUEST TASKS: \n" << doc.toString( 2 ) << endl;
 
   mLoadTodosJob = TDEIO::davPropFind( url, doc, "0", false );
-  connect( mLoadTodosJob, TQT_SIGNAL( result( TDEIO::Job * ) ),
-           TQT_SLOT( slotLoadTodosResult( TDEIO::Job * ) ) );
-  connect( mLoadTodosJob, TQT_SIGNAL( percent( TDEIO::Job *, unsigned long ) ),
-           TQT_SLOT( slotTodosProgress( TDEIO::Job *, unsigned long ) ) );
+  connect( mLoadTodosJob, TQ_SIGNAL( result( TDEIO::Job * ) ),
+           TQ_SLOT( slotLoadTodosResult( TDEIO::Job * ) ) );
+  connect( mLoadTodosJob, TQ_SIGNAL( percent( TDEIO::Job *, unsigned long ) ),
+           TQ_SLOT( slotTodosProgress( TDEIO::Job *, unsigned long ) ) );
 
   mLoadTodosProgress = KPIM::ProgressManager::instance()->createProgressItem(
       KPIM::ProgressManager::getUniqueID(), i18n("Downloading to-dos") );
   connect( mLoadTodosProgress,
-           TQT_SIGNAL( progressItemCanceled( KPIM::ProgressItem * ) ),
-           TQT_SLOT( cancelLoadTodos() ) );
+           TQ_SIGNAL( progressItemCanceled( KPIM::ProgressItem * ) ),
+           TQ_SLOT( cancelLoadTodos() ) );
 
   mPrefs->setLastTodoSync( TQDateTime::currentDateTime() );
 }
@@ -380,16 +380,16 @@ void KCalResourceSlox::uploadIncidences()
   kdDebug() << "UPLOAD: \n" << doc.toString( 2 ) << endl;
 
   mUploadJob = TDEIO::davPropPatch( url, doc, false );
-  connect( mUploadJob, TQT_SIGNAL( result( TDEIO::Job * ) ),
-           TQT_SLOT( slotUploadResult( TDEIO::Job * ) ) );
-  connect( mUploadJob, TQT_SIGNAL( percent( TDEIO::Job *, unsigned long ) ),
-           TQT_SLOT( slotUploadProgress( TDEIO::Job *, unsigned long ) ) );
+  connect( mUploadJob, TQ_SIGNAL( result( TDEIO::Job * ) ),
+           TQ_SLOT( slotUploadResult( TDEIO::Job * ) ) );
+  connect( mUploadJob, TQ_SIGNAL( percent( TDEIO::Job *, unsigned long ) ),
+           TQ_SLOT( slotUploadProgress( TDEIO::Job *, unsigned long ) ) );
 
   mUploadProgress = KPIM::ProgressManager::instance()->createProgressItem(
       KPIM::ProgressManager::getUniqueID(), i18n("Uploading incidence") );
   connect( mUploadProgress,
-           TQT_SIGNAL( progressItemCanceled( KPIM::ProgressItem * ) ),
-           TQT_SLOT( cancelUpload() ) );
+           TQ_SIGNAL( progressItemCanceled( KPIM::ProgressItem * ) ),
+           TQ_SLOT( cancelUpload() ) );
 }
 
 void KCalResourceSlox::createIncidenceAttributes( TQDomDocument &doc,
